import 'package:flutter/widgets.dart';
import 'package:flutter_svg/flutter_svg.dart';

class Gen {
  const Gen();

  SrcGen get src => const SrcGen();
}

class SrcGen {
  const SrcGen();

  SrcAssetsGen get assets => const SrcAssetsGen();
}

class SrcAssetsGen {
  const SrcAssetsGen();

  SrcAssetsPngsGen get pngs => const SrcAssetsPngsGen();
  SrcAssetsSvgsGen get svgs => const SrcAssetsSvgsGen();
}

class SrcAssetsPngsGen {
  const SrcAssetsPngsGen();

  /// File path: lib/src/assets/pngs/Logo.png
  AssetGenImage get logo => const AssetGenImage('lib/src/assets/pngs/Logo.png');

  /// File path: lib/src/assets/pngs/barcode.png
  AssetGenImage get barcode =>
      const AssetGenImage('lib/src/assets/pngs/barcode.png');

  /// File path: lib/src/assets/pngs/barcode.png
  AssetGenImage get loadingState =>
      const AssetGenImage('lib/src/assets/pngs/loading-state.gif');

  /// List of all assets
  List<AssetGenImage> get values => [logo, barcode, loadingState];
}

class SrcAssetsSvgsGen {
  const SrcAssetsSvgsGen();

  /// File path: lib/src/assets/svgs/back.svg
  SvgGenImage get back => const SvgGenImage('lib/src/assets/svgs/back.svg');

  /// File path: lib/src/assets/svgs/barcode.svg
  SvgGenImage get barcode =>
      const SvgGenImage('lib/src/assets/svgs/barcode.svg');

  /// File path: lib/src/assets/svgs/btc.svg
  SvgGenImage get btc => const SvgGenImage('lib/src/assets/svgs/btc.svg');

  /// File path: lib/src/assets/svgs/busha.svg
  SvgGenImage get busha => const SvgGenImage('lib/src/assets/svgs/busha.svg');

  /// File path: lib/src/assets/svgs/cancel.svg
  SvgGenImage get cancel => const SvgGenImage('lib/src/assets/svgs/cancel.svg');

  /// File path: lib/src/assets/svgs/close.svg
  SvgGenImage get close => const SvgGenImage('lib/src/assets/svgs/close.svg');

  /// File path: lib/src/assets/svgs/done_blue.svg
  SvgGenImage get doneBlue =>
      const SvgGenImage('lib/src/assets/svgs/done_blue.svg');

  /// File path: lib/src/assets/svgs/done_yellow.svg
  SvgGenImage get doneYellow =>
      const SvgGenImage('lib/src/assets/svgs/done_yellow.svg');

  /// File path: lib/src/assets/svgs/expired.svg
  SvgGenImage get expired =>
      const SvgGenImage('lib/src/assets/svgs/expired.svg');

  /// File path: lib/src/assets/svgs/header_bg_blue.svg
  SvgGenImage get headerBgBlue =>
      const SvgGenImage('lib/src/assets/svgs/header_bg_blue.svg');

  /// File path: lib/src/assets/svgs/header_bg_yellow.svg
  SvgGenImage get headerBgYellow =>
      const SvgGenImage('lib/src/assets/svgs/header_bg_yellow.svg');

  /// File path: lib/src/assets/svgs/link.svg
  SvgGenImage get link => const SvgGenImage('lib/src/assets/svgs/link.svg');

  /// File path: lib/src/assets/svgs/next.svg
  SvgGenImage get next => const SvgGenImage('lib/src/assets/svgs/next.svg');

  /// File path: lib/src/assets/svgs/processing.svg
  SvgGenImage get processing =>
      const SvgGenImage('lib/src/assets/svgs/processing.svg');

  /// File path: lib/src/assets/svgs/right.svg
  SvgGenImage get right => const SvgGenImage('lib/src/assets/svgs/right.svg');

  /// File path: lib/src/assets/svgs/verification.svg
  SvgGenImage get verification =>
      const SvgGenImage('lib/src/assets/svgs/verification.svg');

  /// File path: lib/src/assets/svgs/wallet.svg
  SvgGenImage get wallet => const SvgGenImage('lib/src/assets/svgs/wallet.svg');

  /// File path: lib/src/assets/svgs/eye.svg
  SvgGenImage get eye => const SvgGenImage('lib/src/assets/svgs/eye.svg');

  /// File path: lib/src/assets/svgs/hide.svg
  SvgGenImage get hide => const SvgGenImage('lib/src/assets/svgs/hide.svg');

  /// List of all assets
  List<SvgGenImage> get values => [
        back,
        barcode,
        btc,
        busha,
        cancel,
        close,
        doneBlue,
        doneYellow,
        expired,
        headerBgBlue,
        headerBgYellow,
        link,
        next,
        processing,
        right,
        verification,
        wallet,
        eye,
        hide
      ];
}

class Assets {
  Assets._();

  static const Gen lib = Gen();
}

class AssetGenImage {
  const AssetGenImage(this._assetName);

  final String _assetName;

  Image image({
    Key? key,
    AssetBundle? bundle,
    ImageFrameBuilder? frameBuilder,
    ImageErrorWidgetBuilder? errorBuilder,
    String? semanticLabel,
    bool excludeFromSemantics = false,
    double? scale,
    double? width,
    double? height,
    Color? color,
    Animation<double>? opacity,
    BlendMode? colorBlendMode,
    BoxFit? fit,
    AlignmentGeometry alignment = Alignment.center,
    ImageRepeat repeat = ImageRepeat.noRepeat,
    Rect? centerSlice,
    bool matchTextDirection = false,
    bool gaplessPlayback = false,
    bool isAntiAlias = false,
    String? package,
    FilterQuality filterQuality = FilterQuality.low,
    int? cacheWidth,
    int? cacheHeight,
  }) {
    return Image.asset(
      _assetName,
      key: key,
      bundle: bundle,
      frameBuilder: frameBuilder,
      errorBuilder: errorBuilder,
      semanticLabel: semanticLabel,
      excludeFromSemantics: excludeFromSemantics,
      scale: scale,
      width: width,
      height: height,
      color: color,
      opacity: opacity,
      colorBlendMode: colorBlendMode,
      fit: fit,
      alignment: alignment,
      repeat: repeat,
      centerSlice: centerSlice,
      matchTextDirection: matchTextDirection,
      gaplessPlayback: gaplessPlayback,
      isAntiAlias: isAntiAlias,
      package: package,
      filterQuality: filterQuality,
      cacheWidth: cacheWidth,
      cacheHeight: cacheHeight,
    );
  }

  ImageProvider provider() => AssetImage(_assetName);

  String get path => _assetName;

  String get keyName => _assetName;
}

class SvgGenImage {
  const SvgGenImage(this._assetName);

  final String _assetName;

  SvgPicture svg({
    Key? key,
    bool matchTextDirection = false,
    AssetBundle? bundle,
    String? package,
    double? width,
    double? height,
    BoxFit fit = BoxFit.contain,
    AlignmentGeometry alignment = Alignment.center,
    bool allowDrawingOutsideViewBox = false,
    WidgetBuilder? placeholderBuilder,
    String? semanticsLabel,
    bool excludeFromSemantics = false,
    SvgTheme theme = const SvgTheme(),
    ColorFilter? colorFilter,
    Color? color,
    BlendMode colorBlendMode = BlendMode.srcIn,
    Clip? clipBehavior,
    bool cacheColorFilter = false,
  }) {
    return SvgPicture.asset(
      _assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      theme: theme,
      color: color,
      colorBlendMode: colorBlendMode,
      cacheColorFilter: cacheColorFilter,
    );
  }

  String get path => _assetName;

  String get keyName => _assetName;
}
