import 'dart:async';
import 'dart:developer';

import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/core/constants/global.dart';
import 'package:busha_commerce_flutter/src/core/model/response/payment_response.dart';
import 'package:busha_commerce_flutter/src/utils/navigation_handler.dart';
import 'package:flutter/material.dart';
import 'package:modal_bottom_sheet/modal_bottom_sheet.dart';

import '../services/commerce_service.dart';

enum PaymentType {
  checkout,
  invoice,
}

/// BushaCommerce is all the client side need to intialize to start the sdk
class BushaCommerce {
  static final BushaCommerce _bushaCommerce = BushaCommerce._();
  BushaCommerce._();

  bool sdkInitialised = false;
  BuildContext? _paymentContext;

  /// Initialise
  /// This allow our commerce sdk to be easily instantiated before use to allow it hold important
  /// passed variables before using.
  factory BushaCommerce({
    required BuildContext context,
    required String businessToken,
    required String url,
    required String customerName,
    required String customerEmail,
    Color? primaryColor,
    Color? secondaryColor,
    Color? primaryTextColor,
    Color? secondaryTextColor,
    PaymentType paymentType = PaymentType.checkout,
  }) {
    _bushaCommerce._paymentContext = context;

    log('initializing Busha_commerce sdk...');

    if (_bushaCommerce.sdkInitialised == false) {
      locatorSetup();
    }

    _bushaCommerce.sdkInitialised = true;
    log('Busha_commerce sdk initialised: ${_bushaCommerce.sdkInitialised}');

    String id = Uri.parse(url).pathSegments.last;
    paymentId = id;
    commercePaymentType = paymentType;
    commerceBusinessToken = businessToken;

    final commerceService = serviceLocator<CommerceService>();

    commerceService.customerEmail = customerEmail;
    commerceService.customerName = customerName;

    return _bushaCommerce;
  }

  Future<void> startPayment({
    Function(dynamic data)? onClose,
    Function(PaymentResponse? data)? onCompleted,
  }) async {
    final commerceService = serviceLocator<CommerceService>();
    final navigationHandler = serviceLocator<NavigationHandler>();

    navigationHandler.currentPushCount = 0;
    commerceService.bushaCommerceResponse = null;

    showMaterialModalBottomSheet(
      context: _bushaCommerce._paymentContext!,
      isDismissible: false,
      enableDrag: false,
      builder: (context) => const EntryView(),
    ).then((value) {
      if (commerceService.bushaCommerceResponse != null) {
        onCompleted!(commerceService.bushaCommerceResponse);
      } else {
        onClose!({
          "commerce_status": "Payment closed",
          "commerce_data": commercePaymentType == PaymentType.checkout
              ? commerceService.checkoutResponse!.toJson().toString()
              : commerceService.invoicesResponse!
        });
      }
    });
  }
}
