import 'dart:convert';

class CancelChargeResponse {
  CancelChargeResponse({
    required this.status,
    required this.message,
    required this.data,
  });

  final String status;
  final String message;
  final Data data;



  factory CancelChargeResponse.fromRawJson(String str) =>
      CancelChargeResponse.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory CancelChargeResponse.fromJson(Map<String, dynamic> json) =>
      CancelChargeResponse(
        status: json["status"],
        message: json["message"],
        data: Data.fromJson(json["data"]),
      );

  Map<String, dynamic> toJson() => {
        "status": status,
        "message": message,
        "data": data.toJson(),
      };
}

class Data {
  Data({
    required this.id,
    required this.businessId,
    required this.reference,
    required this.hostedUrl,
    required this.priceFixed,
    required this.meta,
    required this.expiresAt,
    required this.timeline,
    required this.address,
    required this.payment,
    required this.pricing,
  });

  final String id;
  final String businessId;
  final String reference;
  final String hostedUrl;
  final bool priceFixed;
  final Meta meta;
  final DateTime expiresAt;
  final List<Timeline> timeline;
  final List<dynamic> address;
  final List<dynamic> payment;
  final List<Pricing> pricing;



  factory Data.fromRawJson(String str) => Data.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory Data.fromJson(Map<String, dynamic> json) => Data(
        id: json["id"],
        businessId: json["business_id"],
        reference: json["reference"],
        hostedUrl: json["hosted_url"],
        priceFixed: json["price_fixed"],
        meta: Meta.fromJson(json["meta"]),
        expiresAt: DateTime.parse(json["expires_at"]),
        timeline: List<Timeline>.from(
            json["timeline"].map((x) => Timeline.fromJson(x))),
        address: List<dynamic>.from(json["address"].map((x) => x)),
        payment: List<dynamic>.from(json["payment"].map((x) => x)),
        pricing:
            List<Pricing>.from(json["pricing"].map((x) => Pricing.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "id": id,
        "business_id": businessId,
        "reference": reference,
        "hosted_url": hostedUrl,
        "price_fixed": priceFixed,
        "meta": meta.toJson(),
        "expires_at": expiresAt.toIso8601String(),
        "timeline": List<dynamic>.from(timeline.map((x) => x.toJson())),
        "address": List<dynamic>.from(address.map((x) => x)),
        "payment": List<dynamic>.from(payment.map((x) => x)),
        "pricing": List<dynamic>.from(pricing.map((x) => x.toJson())),
      };
}

class Meta {
  Meta({
    required this.name,
    required this.email,
  });

  final String name;
  final String email;

  factory Meta.fromRawJson(String str) => Meta.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory Meta.fromJson(Map<String, dynamic> json) => Meta(
        name: json["name"],
        email: json["email"],
      );

  Map<String, dynamic> toJson() => {
        "name": name,
        "email": email,
      };
}

class Pricing {
  Pricing({
    required this.currencyId,
    required this.amount,
    required this.rate,
  });

  final String currencyId;
  final int amount;
  final int rate;


  factory Pricing.fromRawJson(String str) => Pricing.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory Pricing.fromJson(Map<String, dynamic> json) => Pricing(
        currencyId: json["currency_id"],
        amount: json["amount"],
        rate: json["rate"],
      );

  Map<String, dynamic> toJson() => {
        "currency_id": currencyId,
        "amount": amount,
        "rate": rate,
      };
}

class Timeline {
  Timeline({
    required this.status,
    required this.context,
    required this.createdAt,
  });

  final String status;
  final String context;
  final DateTime createdAt;


  factory Timeline.fromRawJson(String str) =>
      Timeline.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory Timeline.fromJson(Map<String, dynamic> json) => Timeline(
        status: json["status"],
        context: json["context"],
        createdAt: DateTime.parse(json["created_at"]),
      );

  Map<String, dynamic> toJson() => {
        "status": status,
        "context": context,
        "created_at": createdAt.toIso8601String(),
      };
}
