import 'package:busha_commerce_flutter/src/core/model/response/supported_asset_response.dart';

class CreateChargesResponse {
  CreateChargesResponse({
    this.status,
    this.message,
    this.data,
  });

  String? status;
  String? message;
  CreateChargesData? data;

  factory CreateChargesResponse.fromJson(Map<String, dynamic> json) => CreateChargesResponse(
    status: json["status"],
    message: json["message"],
    data: CreateChargesData.fromJson(json["data"]),
  );

  Map<String, dynamic> toJson() => {
    "status": status,
    "message": message,
    "data": data!.toJson(),
  };

   @override
  String toString() {
    return 'data: $data';
  }
}

class CreateChargesData {
  CreateChargesData({
    this.businessName,
    this.id,
    this.businessId,
    this.reference,
    this.hostedUrl,
    this.priceFixed,
    this.meta,
    this.expiresAt,
    this.timeline,
    this.supportedAssets,
    this.paymentThreshold,
    this.payments,
    this.pricing,
    this.addresses,
    this.localAmount,
    this.localCurrency,
  });

  String? businessName;
  String? id;
  String? businessId;
  String? reference;
  String? hostedUrl;
  bool? priceFixed;
  ListChargesMeta? meta;
  DateTime? expiresAt;
  List<ListChargesTimeline>? timeline;
  List<SupportedAsset>? supportedAssets;
  PaymentThreshold? paymentThreshold;
  List<dynamic>? payments;
  List<ListChargesPricing>? pricing;
  List<ListChargesAddress>? addresses;
  String? localAmount;
  String? localCurrency;


  factory CreateChargesData.fromJson(Map<String, dynamic> json) => CreateChargesData(
    businessName: json["business_name"],
    id: json["id"],
    businessId: json["business_id"],
    reference: json["reference"],
    hostedUrl: json["hosted_url"],
    priceFixed: json["price_fixed"],
    meta: json["meta"].length > 0 ? ListChargesMeta() : ListChargesMeta.fromJson(json["meta"]),
    expiresAt: DateTime.parse(json["expires_at"]),
    timeline: json["timeline"] != null ? List<ListChargesTimeline>.from(json["timeline"].map((x) => ListChargesTimeline.fromJson(x))) : [],
    supportedAssets: json["supported_assets"] != null ? List<SupportedAsset>.from(json["supported_assets"].map((x) => SupportedAsset.fromJson(x))) : [],
    paymentThreshold: PaymentThreshold.fromJson(json["payment_threshold"]),
    payments: List<dynamic>.from(json["payments"].map((x) => x)),
    pricing: List<ListChargesPricing>.from(json["pricing"].map((x) => ListChargesPricing.fromJson(x))),
    addresses: List<ListChargesAddress>.from(json["addresses"].map((x) => ListChargesAddress.fromJson(x))),
    localAmount: json["local_amount"],
    localCurrency: json["local_currency"],
  );

  Map<String, dynamic> toJson() => {
    "business_name": businessName,
    "id": id,
    "business_id": businessId,
    "reference": reference,
    "hosted_url": hostedUrl,
    "price_fixed": priceFixed,
    "meta": meta!.toJson(),
    "expires_at": expiresAt!.toIso8601String(),
    "timeline": List<dynamic>.from(timeline!.map((x) => x.toJson())),
    "supported_assets": List<dynamic>.from(supportedAssets!.map((x) => x.toJson())),
    "payment_threshold": paymentThreshold!.toJson(),
    "payments": List<dynamic>.from(payments!.map((x) => x)),
    "pricing": List<dynamic>.from(pricing!.map((x) => x.toJson())),
    "addresses": List<dynamic>.from(addresses!.map((x) => x.toJson())),
    "local_amount": localAmount,
    "local_currency": localCurrency,
  };
}

class PaymentThreshold {
  PaymentThreshold({
    this.overpaymentAbsoluteThreshold,
    this.overpaymentRelativeThreshold,
    this.underpaymentAbsoluteThreshold,
    this.underpaymentRelativeThreshold,
  });

  String? overpaymentAbsoluteThreshold;
  String? overpaymentRelativeThreshold;
  String? underpaymentAbsoluteThreshold;
  String? underpaymentRelativeThreshold;


  factory PaymentThreshold.fromJson(Map<String, dynamic> json) => PaymentThreshold(
    overpaymentAbsoluteThreshold: json["overpayment_absolute_threshold"],
    overpaymentRelativeThreshold: json["overpayment_relative_threshold"],
    underpaymentAbsoluteThreshold: json["underpayment_absolute_threshold"],
    underpaymentRelativeThreshold: json["underpayment_relative_threshold"],
  );

  Map<String, dynamic> toJson() => {
    "overpayment_absolute_threshold": overpaymentAbsoluteThreshold,
    "overpayment_relative_threshold": overpaymentRelativeThreshold,
    "underpayment_absolute_threshold": underpaymentAbsoluteThreshold,
    "underpayment_relative_threshold": underpaymentRelativeThreshold,
  };
}

class ListChargesAddress {
  ListChargesAddress({
    this.currencyId,
    this.address,
    this.chain,
    this.memo
  });

  String? currencyId;
  String? address;
  String? chain;
  String? memo;

  ListChargesAddress copyWith({
    String? currencyId,
    String? address,
    String? chain,
    String? memo
  }) =>
      ListChargesAddress(
        currencyId: currencyId ?? this.currencyId,
        address: address ?? this.address,
        chain: chain ?? this.chain,
        memo: memo ?? this.memo,
      );

  factory ListChargesAddress.fromJson(Map<String, dynamic> json) => ListChargesAddress(
    currencyId: json["currency_id"],
    address: json["address"],
    chain: json["chain"],
    memo: json["memo"],
  );

  Map<String, dynamic> toJson() => {
    "currency_id": currencyId,
    "address": address,
    "chain": chain,
    "memo": memo,
  };
}

class ListChargesMeta {
  ListChargesMeta({
    this.name,
    this.email,
  });

  String? name;
  String? email;

  ListChargesMeta copyWith({
    String? name,
    String? email,
  }) =>
      ListChargesMeta(
        name: name ?? this.name,
        email: email ?? this.email,
      );

  factory ListChargesMeta.fromJson(Map<String, dynamic> json) => ListChargesMeta(
    name: json["name"],
    email: json["email"],
  );

  Map<String, dynamic> toJson() => {
    "name": name,
    "email": email,
  };
}

class ListChargesPricing {
  ListChargesPricing({
    this.currencyId,
    this.amount,
    this.rate,
  });

  String? currencyId;
  String? amount;
  String? rate;

  factory ListChargesPricing.fromJson(Map<String, dynamic> json) => ListChargesPricing(
    currencyId: json["currency_id"],
    amount: json["amount"],
    rate: json["rate"],
  );

  Map<String, dynamic> toJson() => {
    "currency_id": currencyId,
    "amount": amount,
    "rate": rate,
  };
}

class ListChargesTimeline {
  ListChargesTimeline({
    this.status,
    this.context,
    this.createdAt,
  });

  String? status;
  String? context;
  DateTime? createdAt;

  ListChargesTimeline copyWith({
    String? status,
    String? context,
    DateTime? createdAt,
  }) =>
      ListChargesTimeline(
        status: status ?? this.status,
        context: context ?? this.context,
        createdAt: createdAt ?? this.createdAt,
      );

  factory ListChargesTimeline.fromJson(Map<String, dynamic> json) => ListChargesTimeline(
    status: json["status"],
    context: json["context"],
    createdAt: DateTime.parse(json["created_at"]),
  );

  Map<String, dynamic> toJson() => {
    "status": status,
    "context": context,
    "created_at": createdAt!.toIso8601String(),
  };
}