import 'dart:convert';

import 'supported_asset_response.dart';

class CreateInvoicesResponse {
    CreateInvoicesResponse({
        required this.status,
        required this.message,
        required this.data,
    });

    final String status;
    final String message;
    final CreateInvoiceResponseData data;

    factory CreateInvoicesResponse.fromRawJson(String str) => CreateInvoicesResponse.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory CreateInvoicesResponse.fromJson(Map<String, dynamic> json) => CreateInvoicesResponse(
        status: json["status"],
        message: json["message"],
        data: CreateInvoiceResponseData.fromJson(json["data"]),
    );

    Map<String, dynamic> toJson() => {
        "status": status,
        "message": message,
        "data": data.toJson(),
    };
}

class CreateInvoiceResponseData {
    CreateInvoiceResponseData({
        required this.businessName,
        required this.id,
        required this.businessId,
        required this.reference,
        required this.hostedUrl,
        required this.priceFixed,
        required this.callbackUrl,
        required this.meta,
        required this.expiresAt,
        required this.timeline,
        required this.supportedAssets,
        required this.paymentThreshold,
        required this.payment,
        required this.pricing,
        required this.localAmount,
        required this.localCurrency,
    });

    final String businessName;
    final String id;
    final String businessId;
    final String reference;
    final String hostedUrl;
    final bool priceFixed;
    final String callbackUrl;
    final Meta meta;
    final DateTime expiresAt;
    final List<Timeline> timeline;
    final List<SupportedAsset> supportedAssets;
    final PaymentThreshold paymentThreshold;
    final dynamic payment;
    final List<Pricing> pricing;
    final String localAmount;
    final String localCurrency;

    factory CreateInvoiceResponseData.fromRawJson(String str) => CreateInvoiceResponseData.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory CreateInvoiceResponseData.fromJson(Map<String, dynamic> json) => CreateInvoiceResponseData(
        businessName: json["business_name"],
        id: json["id"],
        businessId: json["business_id"],
        reference: json["reference"],
        hostedUrl: json["hosted_url"],
        priceFixed: json["price_fixed"],
        callbackUrl: json["callback_url"],
        meta: Meta.fromJson(json["meta"]),
        expiresAt: DateTime.parse(json["expires_at"]),
        timeline: List<Timeline>.from(json["timeline"].map((x) => Timeline.fromJson(x))),
        supportedAssets: List<SupportedAsset>.from(json["supported_assets"].map((x) => SupportedAsset.fromJson(x))),
        paymentThreshold: PaymentThreshold.fromJson(json["payment_threshold"]),
        payment: json["payment"],
        pricing: List<Pricing>.from(json["pricing"].map((x) => Pricing.fromJson(x))),
        localAmount: json["local_amount"],
        localCurrency: json["local_currency"],
    );

    Map<String, dynamic> toJson() => {
        "business_name": businessName,
        "id": id,
        "business_id": businessId,
        "reference": reference,
        "hosted_url": hostedUrl,
        "price_fixed": priceFixed,
        "callback_url": callbackUrl,
        "meta": meta.toJson(),
        "expires_at": expiresAt.toIso8601String(),
        "timeline": List<dynamic>.from(timeline.map((x) => x.toJson())),
        "supported_assets": List<dynamic>.from(supportedAssets.map((x) => x.toJson())),
        "payment_threshold": paymentThreshold.toJson(),
        "payment": payment,
        "pricing": List<dynamic>.from(pricing.map((x) => x.toJson())),
        "local_amount": localAmount,
        "local_currency": localCurrency,
    };
}

class Meta {
    Meta({
        required this.name,
        required this.email,
    });

    final String name;
    final String email;

    factory Meta.fromRawJson(String str) => Meta.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory Meta.fromJson(Map<String, dynamic> json) => Meta(
        name: json["name"],
        email: json["email"],
    );

    Map<String, dynamic> toJson() => {
        "name": name,
        "email": email,
    };
}

class PaymentThreshold {
    PaymentThreshold({
        required this.overpaymentAbsoluteThreshold,
        required this.overpaymentRelativeThreshold,
        required this.underpaymentAbsoluteThreshold,
        required this.underpaymentRelativeThreshold,
    });

    final String overpaymentAbsoluteThreshold;
    final String overpaymentRelativeThreshold;
    final String underpaymentAbsoluteThreshold;
    final String underpaymentRelativeThreshold;

    factory PaymentThreshold.fromRawJson(String str) => PaymentThreshold.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory PaymentThreshold.fromJson(Map<String, dynamic> json) => PaymentThreshold(
        overpaymentAbsoluteThreshold: json["overpayment_absolute_threshold"],
        overpaymentRelativeThreshold: json["overpayment_relative_threshold"],
        underpaymentAbsoluteThreshold: json["underpayment_absolute_threshold"],
        underpaymentRelativeThreshold: json["underpayment_relative_threshold"],
    );

    Map<String, dynamic> toJson() => {
        "overpayment_absolute_threshold": overpaymentAbsoluteThreshold,
        "overpayment_relative_threshold": overpaymentRelativeThreshold,
        "underpayment_absolute_threshold": underpaymentAbsoluteThreshold,
        "underpayment_relative_threshold": underpaymentRelativeThreshold,
    };
}

class Pricing {
    Pricing({
        required this.currencyId,
        required this.amount,
        required this.rate,
    });

    final String currencyId;
    final String amount;
    final String rate;

    factory Pricing.fromRawJson(String str) => Pricing.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory Pricing.fromJson(Map<String, dynamic> json) => Pricing(
        currencyId: json["currency_id"],
        amount: json["amount"],
        rate: json["rate"],
    );

    Map<String, dynamic> toJson() => {
        "currency_id": currencyId,
        "amount": amount,
        "rate": rate,
    };
}



class Timeline {
    Timeline({
        required this.status,
        required this.createdAt,
    });

    final String status;
    final DateTime createdAt;

    factory Timeline.fromRawJson(String str) => Timeline.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory Timeline.fromJson(Map<String, dynamic> json) => Timeline(
        status: json["status"],
        createdAt: DateTime.parse(json["created_at"]),
    );

    Map<String, dynamic> toJson() => {
        "status": status,
        "created_at": createdAt.toIso8601String(),
    };
}