import 'dart:convert';

class GenerateAddressResponse {
  GenerateAddressResponse({
    required this.status,
    required this.message,
    required this.data,
  });

  final String status;
  final String message;
  final GenerateAddressData data;

  factory GenerateAddressResponse.fromRawJson(String str) =>
      GenerateAddressResponse.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory GenerateAddressResponse.fromJson(Map<String, dynamic> json) =>
      GenerateAddressResponse(
        status: json["status"],
        message: json["message"],
        data: GenerateAddressData.fromJson(json["data"]),
      );

  Map<String, dynamic> toJson() => {
        "status": status,
        "message": message,
        "data": data.toJson(),
      };
}

class GenerateAddressData {
  GenerateAddressData({
    required this.addresses,
    required this.pricing,
  });

  final List<Address> addresses;
  final List<GenerateAddressPricing> pricing;

  factory GenerateAddressData.fromRawJson(String str) => GenerateAddressData.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory GenerateAddressData.fromJson(Map<String, dynamic> json) => GenerateAddressData(
        addresses: List<Address>.from(
          json["addresses"].map(
            (x) => Address.fromJson(x),
          ),
        ),
        pricing: List<GenerateAddressPricing>.from(
          json["pricing"].map(
            (x) => GenerateAddressPricing.fromJson(x),
          ),
        ),
      );

  Map<String, dynamic> toJson() => {
        "addresses": List<dynamic>.from(
          addresses.map(
            (x) => x.toJson(),
          ),
        ),
        "pricing": List<dynamic>.from(
          pricing.map(
            (x) => x.toJson(),
          ),
        ),
      };
}

class Address {
  Address({
    required this.currencyId,
    required this.chain,
    required this.address,
    required this.memo,
  });

  final String currencyId;
  final String chain;
  final String address;
  final String memo;

  factory Address.fromRawJson(String str) => Address.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory Address.fromJson(Map<String, dynamic> json) => Address(
        currencyId: json["currency_id"],
        chain: json["chain"],
        address: json["address"],
        memo: json["memo"],
      );

  Map<String, dynamic> toJson() => {
        "currency_id": currencyId,
        "chain": chain,
        "address": address,
        "memo": memo,
      };
}

class GenerateAddressPricing {
  GenerateAddressPricing({
    required this.currencyId,
    required this.amount,
    required this.rate,
  });

  final String currencyId;
  final double amount;
  final double rate;

  factory GenerateAddressPricing.fromRawJson(String str) => GenerateAddressPricing.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory GenerateAddressPricing.fromJson(Map<String, dynamic> json) => GenerateAddressPricing(
        currencyId: json["currency_id"],
        amount: json["amount"]?.toDouble(),
        rate: json["rate"]?.toDouble(),
      );

  Map<String, dynamic> toJson() => {
        "currency_id": currencyId,
        "amount": amount,
        "rate": rate,
      };
}
