
import 'dart:convert';

class InvoicesResponse {
    InvoicesResponse({
        required this.status,
        required this.message,
        required this.data,
    });

    final String status;
    final String message;
    final InvoiceData data;

    factory InvoicesResponse.fromRawJson(String str) => InvoicesResponse.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory InvoicesResponse.fromJson(Map<String, dynamic> json) => InvoicesResponse(
        status: json["status"],
        message: json["message"],
        data: InvoiceData.fromJson(json["data"]),
    );

    Map<String, dynamic> toJson() => {
        "status": status,
        "message": message,
        "data": data.toJson(),
    };
}

class InvoiceData {
    InvoiceData({
        required this.id,
        required this.businessId,
        required this.name,
        required this.description,
        required this.customerName,
        required this.customerEmail,
        required this.localAmount,
        required this.localCurrency,
        required this.status,
        required this.reference,
        required this.createdAt,
        required this.updatedAt,
        required this.dueDate,
    });

    final String id;
    final String businessId;
    final String name;
    final String description;
    final String customerName;
    final String customerEmail;
    final String localAmount;
    final String localCurrency;
    final String status;
    final String reference;
    final DateTime createdAt;
    final DateTime updatedAt;
    final DateTime dueDate;

    factory InvoiceData.fromRawJson(String str) => InvoiceData.fromJson(json.decode(str));

    String toRawJson() => json.encode(toJson());

    factory InvoiceData.fromJson(Map<String, dynamic> json) => InvoiceData(
        id: json["id"],
        businessId: json["business_id"],
        name: json["name"],
        description: json["description"],
        customerName: json["customer_name"],
        customerEmail: json["customer_email"],
        localAmount: json["local_amount"],
        localCurrency: json["local_currency"],
        status: json["status"],
        reference: json["reference"],
        createdAt: DateTime.parse(json["created_at"]),
        updatedAt: DateTime.parse(json["updated_at"]),
        dueDate: DateTime.parse(json["due_date"]),
    );

    Map<String, dynamic> toJson() => {
        "id": id,
        "business_id": businessId,
        "name": name,
        "description": description,
        "customer_name": customerName,
        "customer_email": customerEmail,
        "local_amount": localAmount,
        "local_currency": localCurrency,
        "status": status,
        "reference": reference,
        "created_at": createdAt.toIso8601String(),
        "updated_at": updatedAt.toIso8601String(),
        "due_date": dueDate.toIso8601String(),
    };
}
