import 'dart:convert';

class ResolveChargeResponse {
  ResolveChargeResponse({
    required this.status,
    required this.message,
    required this.data,
  });

  String status;
  String message;
  ResolveChargeData data;



  factory ResolveChargeResponse.fromRawJson(String str) =>
      ResolveChargeResponse.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory ResolveChargeResponse.fromJson(Map<String, dynamic> json) =>
      ResolveChargeResponse(
        status: json["status"],
        message: json["message"],
        data: ResolveChargeData.fromJson(json["data"]),
      );

  Map<String, dynamic> toJson() => {
        "status": status,
        "message": message,
        "data": data.toJson(),
      };
}

class ResolveChargeData {
  ResolveChargeData({
    required this.id,
    required this.businessId,
    required this.reference,
    required this.hostedUrl,
    required this.priceFixed,
    required this.callbackUrl,
    required this.meta,
    required this.expiresAt,
    required this.timeline,
    required this.address,
    required this.payment,
    required this.pricing,
  });

  String id;
  String businessId;
  String reference;
  String hostedUrl;
  bool priceFixed;
  String callbackUrl;
  ResolveChargeMeta meta;
  DateTime expiresAt;
  List<ResolveTimeline> timeline;
  List<ResolveChargeAddress> address;
  List<Payment> payment;
  List<ResolveChargePricing> pricing;


  factory ResolveChargeData.fromRawJson(String str) => ResolveChargeData.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory ResolveChargeData.fromJson(Map<String, dynamic> json) => ResolveChargeData(
        id: json["id"],
        businessId: json["business_id"],
        reference: json["reference"],
        hostedUrl: json["hosted_url"],
        priceFixed: json["price_fixed"],
        callbackUrl: json["callback_url"],
        meta: ResolveChargeMeta.fromJson(json["meta"]),
        expiresAt: DateTime.parse(json["expires_at"]),
        timeline: List<ResolveTimeline>.from(
          json["timeline"].map(
            (x) => ResolveTimeline.fromJson(x),
          ),
        ),
        address: List<ResolveChargeAddress>.from(
          json["address"].map(
            (x) => ResolveChargeAddress.fromJson(x),
          ),
        ),
        payment: List<Payment>.from(
          json["payment"].map(
            (x) => Payment.fromJson(x),
          ),
        ),
        pricing: List<ResolveChargePricing>.from(
          json["pricing"].map(
            (x) => ResolveChargePricing.fromJson(x),
          ),
        ),
      );

  Map<String, dynamic> toJson() => {
        "id": id,
        "business_id": businessId,
        "reference": reference,
        "hosted_url": hostedUrl,
        "price_fixed": priceFixed,
        "callback_url": callbackUrl,
        "meta": meta.toJson(),
        "expires_at": expiresAt.toIso8601String(),
        "timeline": List<dynamic>.from(timeline.map((x) => x.toJson())),
        "address": List<dynamic>.from(address.map((x) => x.toJson())),
        "payment": List<dynamic>.from(payment.map((x) => x.toJson())),
        "pricing": List<dynamic>.from(pricing.map((x) => x.toJson())),
      };
}

class ResolveChargeAddress {
  ResolveChargeAddress({
    required this.currencyId,
    required this.address,
    required this.chain,
  });

  String currencyId;
  String address;
  String chain;


  factory ResolveChargeAddress.fromRawJson(String str) => ResolveChargeAddress.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory ResolveChargeAddress.fromJson(Map<String, dynamic> json) => ResolveChargeAddress(
        currencyId: json["currency_id"],
        address: json["address"],
        chain: json["chain"],
      );

  Map<String, dynamic> toJson() => {
        "currency_id": currencyId,
        "address": address,
        "chain": chain,
      };
}

class ResolveChargeMeta {
  ResolveChargeMeta({
    required this.name,
    required this.email,
  });

  String name;
  String email;



  factory ResolveChargeMeta.fromRawJson(String str) => ResolveChargeMeta.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory ResolveChargeMeta.fromJson(Map<String, dynamic> json) => ResolveChargeMeta(
        name: json["name"],
        email: json["email"],
      );

  Map<String, dynamic> toJson() => {
        "name": name,
        "email": email,
      };
}

class Payment {
  Payment({
    required this.id,
    required this.chargeId,
    required this.localAmount,
    required this.localCurrency,
    required this.amount,
    required this.currency,
    required this.transactionId,
    required this.transactionHash,
    required this.detectedAt,
    required this.status,
    required this.traded,
    required this.confirmation,
    required this.createdAt,
    required this.updatedAt,
    required this.reference,
    required this.chain,
    required this.paymentThreshold,
    required this.address,
    required this.blockUrl,
  });

  String id;
  String chargeId;
  double localAmount;
  String localCurrency;
  double amount;
  String currency;
  String transactionId;
  String transactionHash;
  DateTime detectedAt;
  String status;
  bool traded;
  int confirmation;
  DateTime createdAt;
  DateTime updatedAt;
  String reference;
  String chain;
  ResolvePaymentThreshold paymentThreshold;
  String address;
  String blockUrl;


  factory Payment.fromRawJson(String str) => Payment.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory Payment.fromJson(Map<String, dynamic> json) => Payment(
        id: json["id"],
        chargeId: json["charge_id"],
        localAmount: json["local_amount"]?.toDouble(),
        localCurrency: json["local_currency"],
        amount: json["amount"]?.toDouble(),
        currency: json["currency"],
        transactionId: json["transaction_id"],
        transactionHash: json["transaction_hash"],
        detectedAt: DateTime.parse(json["detected_at"]),
        status: json["status"],
        traded: json["traded"],
        confirmation: json["confirmation"],
        createdAt: DateTime.parse(json["created_at"]),
        updatedAt: DateTime.parse(json["updated_at"]),
        reference: json["reference"],
        chain: json["chain"],
        paymentThreshold: ResolvePaymentThreshold.fromJson(json["payment_threshold"]),
        address: json["address"],
        blockUrl: json["block_url"],
      );

  Map<String, dynamic> toJson() => {
        "id": id,
        "charge_id": chargeId,
        "local_amount": localAmount,
        "local_currency": localCurrency,
        "amount": amount,
        "currency": currency,
        "transaction_id": transactionId,
        "transaction_hash": transactionHash,
        "detected_at": detectedAt.toIso8601String(),
        "status": status,
        "traded": traded,
        "confirmation": confirmation,
        "created_at": createdAt.toIso8601String(),
        "updated_at": updatedAt.toIso8601String(),
        "reference": reference,
        "chain": chain,
        "payment_threshold": paymentThreshold.toJson(),
        "address": address,
        "block_url": blockUrl,
      };
}

class ResolvePaymentThreshold {
  ResolvePaymentThreshold({
    required this.overpaymentAbsoluteThreshold,
    required this.overpaymentRelativeThreshold,
    required this.underpaymentAbsoluteThreshold,
    required this.underpaymentRelativeThreshold,
  });

  int overpaymentAbsoluteThreshold;
  int overpaymentRelativeThreshold;
  int underpaymentAbsoluteThreshold;
  int underpaymentRelativeThreshold;


  factory ResolvePaymentThreshold.fromRawJson(String str) =>
      ResolvePaymentThreshold.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory ResolvePaymentThreshold.fromJson(Map<String, dynamic> json) =>
      ResolvePaymentThreshold(
        overpaymentAbsoluteThreshold: json["overpayment_absolute_threshold"],
        overpaymentRelativeThreshold: json["overpayment_relative_threshold"],
        underpaymentAbsoluteThreshold: json["underpayment_absolute_threshold"],
        underpaymentRelativeThreshold: json["underpayment_relative_threshold"],
      );

  Map<String, dynamic> toJson() => {
        "overpayment_absolute_threshold": overpaymentAbsoluteThreshold,
        "overpayment_relative_threshold": overpaymentRelativeThreshold,
        "underpayment_absolute_threshold": underpaymentAbsoluteThreshold,
        "underpayment_relative_threshold": underpaymentRelativeThreshold,
      };
}

class ResolveChargePricing {
  ResolveChargePricing({
    required this.currencyId,
    required this.amount,
    required this.rate,
  });

  String currencyId;
  double amount;
  int rate;

  factory ResolveChargePricing.fromRawJson(String str) => ResolveChargePricing.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory ResolveChargePricing.fromJson(Map<String, dynamic> json) => ResolveChargePricing(
        currencyId: json["currency_id"],
        amount: json["amount"]?.toDouble(),
        rate: json["rate"],
      );

  Map<String, dynamic> toJson() => {
        "currency_id": currencyId,
        "amount": amount,
        "rate": rate,
      };
}

class ResolveTimeline {
  ResolveTimeline({
    required this.status,
    required this.context,
    required this.createdAt,
  });

  String status;
  String context;
  DateTime createdAt;


  factory ResolveTimeline.fromRawJson(String str) =>
      ResolveTimeline.fromJson(json.decode(str));

  String toRawJson() => json.encode(toJson());

  factory ResolveTimeline.fromJson(Map<String, dynamic> json) => ResolveTimeline(
        status: json["status"],
        context: json["context"],
        createdAt: DateTime.parse(json["created_at"]),
      );

  Map<String, dynamic> toJson() => {
        "status": status,
        "context": context,
        "created_at": createdAt.toIso8601String(),
      };
}
