import 'package:busha_commerce_flutter/src/core/api/api.dart';
import 'package:busha_commerce_flutter/src/core/api/api_exception.dart';
import 'package:busha_commerce_flutter/src/core/services/http_service.dart';
import 'package:busha_commerce_flutter/src/utils/locator_setup.dart';

import '../model/model.dart';

class AuthService {
  final httpService = serviceLocator<HttpService>();

  LoginRequest? loginRequest;
  String? confirmToken;
  String? accountKey;
  String? confirmationMessage;
  User? currentUser;

  Future<LoginResponse> login() async {
    try {
      final response = await httpService.post(
        APIRoutes.login,
        loginRequest!,
        null,
      );
      return LoginResponse.fromJson(response!);
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<ConfirmLoginResponse> confirmLogin() async {
    Map<String, String> headers = {};
    headers['Authorization'] = 'Bearer $confirmToken';
    try {
      final response = await httpService.post(
        APIRoutes.confirmLogin,
        loginRequest!,
        headers,
      );
      return ConfirmLoginResponse.fromJson(response);
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<User> getUser({String? token}) async {
    Map<String, String> headers = {};
    headers['Authorization'] = 'Bearer $accountKey';
    try {
      final profileResponse = await httpService.get(
        APIRoutes.getUser,
        headers: headers,
      );
      currentUser = User.fromJson(profileResponse);
      return currentUser!;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }
}
