import 'dart:developer';

import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/core/api/api_exception.dart';
import 'package:busha_commerce_flutter/src/core/api/api_routes.dart';
import 'package:busha_commerce_flutter/src/core/constants/global.dart';
import 'package:busha_commerce_flutter/src/core/model/model.dart';
import 'package:busha_commerce_flutter/src/core/model/response/create_invoice_response.dart';
import 'package:busha_commerce_flutter/src/core/model/response/payment_response.dart';
import 'package:busha_commerce_flutter/src/core/services/auth_service.dart';
import 'package:busha_commerce_flutter/src/core/services/http_service.dart';

class CommerceService {
  final httpService = serviceLocator<HttpService>();
  final authService = serviceLocator<AuthService>();

  String? currentId = paymentId;
  String? chargeId = '';
  String token = commerceBusinessToken;

  String? customerName;
  String? customerEmail;

  CreateChargesResponse? createChargesResponse;
  GetCheckoutResponse? checkoutResponse;
  InvoicesResponse? invoicesResponse;
  CreateCharges? createCharges;
  CreateInvoicesResponse? createInvoicesResponse;

  PaymentResponse? bushaCommerceResponse;

  /// Track the selected wallet by the user
  Wallet? selectedWallet;

  /// Track the selected asset during external payment
  String? selectedSupportedAsset;

  Future<GetCheckoutResponse> getCheckout() async {
    try {
      Map<String, String> headers = {};
      headers['X-BC-API-KEY'] = token;

      final response = await httpService.get(
        "${APIRoutes.checkout}/$currentId",
        headers: headers,
      );

      checkoutResponse = GetCheckoutResponse.fromJson(response!);

      return checkoutResponse!;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<InvoicesResponse> getInvoices() async {
    try {
      Map<String, String> headers = {};
      headers['X-BC-API-KEY'] = token;

      final response = await httpService.get(
        "${APIRoutes.invoice}/$currentId",
        headers: headers,
      );

      invoicesResponse = InvoicesResponse.fromJson(response!);

      return invoicesResponse!;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<GetCheckoutResponse> generateAddress() async {
    try {
      Map<String, String> headers = {};
      headers['X-BC-API-KEY'] = token;

      final response = await httpService.get(
        "${APIRoutes.address}/$currentId/address",
        headers: headers,
      );

      log(response.toString());
      return checkoutResponse!;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<CreateChargesResponse?> createCheckoutCharge({
    String? localAmount,
    String? localCurrency,
    String? email,
    String? name,
  }) async {
    Map<String, String> headers = {};
    headers['X-BC-API-KEY'] = token;

    createCharges = CreateCharges(
      meta: CreateChargesMeta(
        email: email ?? customerEmail,
        name: name ?? customerName,
      ),
    );

    try {
      final response = await httpService.post(
        '${APIRoutes.checkout}/$currentId/charge',
        createCharges,
        headers,
      );

      createChargesResponse = CreateChargesResponse.fromJson(response);
      chargeId = createChargesResponse!.data!.id;

      return createChargesResponse;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<CreateChargesResponse?> createInvoiceCharge({
    String? localAmount,
    String? localCurrency,
    String? email,
    String? name,
  }) async {
    Map<String, String> headers = {};
    headers['X-BC-API-KEY'] = token;

    createCharges = CreateCharges(
      meta: CreateChargesMeta(
        email: email,
        name: name,
      ),
    );

    try {
      final response = await httpService.post(
        '${APIRoutes.invoice}/$currentId/charge',
        createCharges,
        headers,
      );

      createChargesResponse = CreateChargesResponse.fromJson(response);
      chargeId = createChargesResponse!.data!.id;

      return createChargesResponse;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<String> cancelCharge({PaymentType? paymentType}) async {
    Map<String, String> headers = {};
    headers['X-BC-API-KEY'] = token;

    try {
      final response = await httpService.put(
        '${APIRoutes.charge}/${createChargesResponse!.data!.id}/cancel',
        null,
        headers,
      );

      createChargesResponse = CreateChargesResponse.fromJson(response);

      return createChargesResponse!.message!;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }
}
