import 'package:busha_commerce_flutter/src/core/api/api_exception.dart';
import 'package:busha_commerce_flutter/src/core/core.dart';

import '../../../busha_commerce_flutter.dart';
import 'auth_service.dart';
import 'http_service.dart';

class PayoutService {
  final httpService = serviceLocator<HttpService>();
  final authService = serviceLocator<AuthService>();

  PayoutRequest? payoutRequest;
  PayoutInitializeResponse? payoutInitializeResponse;
  PayoutFinalizeRequest? payoutFinalizeRequest;

  Future<PayoutInitializeResponse?> initializeTransfer() async {
    try {
      Map<String, String> headers = {};
      headers['Authorization'] = 'Bearer ${authService.accountKey}';

      var response = await httpService.post(
          '${APIRoutes.payout}/initialize', payoutRequest, headers);
      payoutInitializeResponse = PayoutInitializeResponse.fromJson(response);

      payoutFinalizeRequest =
          PayoutFinalizeRequest(token: payoutInitializeResponse!.transferToken);

      return payoutInitializeResponse!;
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<String> finalizeTransfer() async {
    try {
      Map<String, String> headers = {};
      headers['Authorization'] = 'Bearer ${authService.accountKey}';

      var response = await httpService.post(
        '${APIRoutes.payout}/finalize',
        payoutFinalizeRequest,
        headers,
      );

      if (response['status'] == 'status') {
        return 'Success';
      }
      return '';
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }

  Future<void> resendCode() async {
    try {
      Map<String, String> headers = {};
      headers['Authorization'] = 'Bearer ${authService.accountKey}';

      await httpService.post(
        '${APIRoutes.payout}/resend',
        payoutFinalizeRequest,
        headers,
      );
    } on Exception catch (e) {
      throw ApiException(e.toString());
    }
  }
}
