import 'dart:async';
import 'dart:convert';
import 'dart:developer';

import 'package:busha_commerce_flutter/src/core/core.dart';
import 'package:busha_commerce_flutter/src/core/model/response/payment_response.dart';
import 'package:busha_commerce_flutter/src/core/services/auth_service.dart';
import 'package:busha_commerce_flutter/src/core/services/commerce_service.dart';
import 'package:busha_commerce_flutter/src/core/services/stoppable_service.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:flutter/foundation.dart';
import 'package:web_socket_channel/io.dart';

import 'package:web_socket_channel/status.dart' as status;

class SocketService implements StoppableService {
  final authService = serviceLocator<AuthService>();
  final commerceService = serviceLocator<CommerceService>();

  IOWebSocketChannel? songBirdChannel;

  final _paymentController = StreamController<PaymentResponse>.broadcast();

  Stream<PaymentResponse> get paymentStream => _paymentController.stream;

  DateTime? lastUpdated;

  Future<void> connectSongbird() async {
    if (songBirdChannel != null) {
      disconnectSongbird();
      await connectSongbird();
      return;
    }
    String? id = commerceService.chargeId;

    if (id != null) {
      final url = Uri.parse(
        '${APIRoutes.socketV2}/commerce/charge?charge_id=$id',
      );
      songBirdChannel = IOWebSocketChannel.connect(url);

      songBirdChannel!.stream.listen(
        (message) {
          debugPrint("Socket $message");
          _processSongbirdMessage(message);
        },
        onError: (error) {
          log('onError: $error');
        },
        onDone: () async {},
      );
    } else {
      return;
    }
  }

  void disconnectSongbird() {
    if (songBirdChannel != null) {
      songBirdChannel!.sink.close(status.normalClosure);
      songBirdChannel = null;
    }
  }

  void sendMessage(String message) {
    if (songBirdChannel != null) {
      songBirdChannel!.sink.add(message);
    }
  }

  void _processSongbirdMessage(dynamic event) {
    try {
      Map<String, dynamic> message = jsonDecode(event);
      var data = PaymentResponse.fromJson(message);
      _paymentController.add(data);
    } catch (e) {
      log(e.toString());
    }
  }

  bool _serviceStopped = false;

  @override
  bool get serviceStopped => _serviceStopped;

  @override
  void start() async {
    _serviceStopped = false;
    await connectSongbird();
  }

  @override
  void stop() {
    _serviceStopped = true;
    disconnectSongbird();
  }
}
