import 'package:flutter/material.dart';

/// BrandTheme allow us to share theme properies across the screen tree
class BrandTheme extends InheritedWidget {
  const BrandTheme({
    super.key,
    this.primaryColor = const Color(0xFF12A633),
    this.secondaryColor = const Color(0xFFF1F1F1),
    this.primaryTextColor = const Color(0xFF000639),
    this.secondaryTextColor = const Color(0xFF5A5C5E),
    required super.child,
  });

  final Color primaryColor;
  final Color secondaryColor;
  final Color primaryTextColor;
  final Color secondaryTextColor;

  static BrandTheme? maybeOf(BuildContext context) {
    return context.dependOnInheritedWidgetOfExactType<BrandTheme>();
  }

  static BrandTheme of(BuildContext context) {
    final BrandTheme? result = maybeOf(context);
    assert(result != null, 'No BrandTheme found in context');
    return result!;
  }

  @override
  bool updateShouldNotify(BrandTheme oldWidget) {
    return primaryColor != oldWidget.primaryColor ||
        secondaryColor != oldWidget.secondaryColor ||
        primaryTextColor != oldWidget.primaryTextColor ||
        secondaryTextColor != oldWidget.secondaryTextColor;
  }
}
