import 'package:flutter/services.dart';
import 'package:intl/intl.dart';

class OtpInputFormatter extends TextInputFormatter {
  @override
  TextEditingValue formatEditUpdate(
    TextEditingValue oldValue,
    TextEditingValue newValue,
  ) {
    final formattedText = newValue.text
        .replaceAll(RegExp(r'\D+'), '')
        .substring(0, newValue.text.length);
    return TextEditingValue(
      text: formattedText,
      selection: TextSelection.collapsed(offset: formattedText.length),
    );
  }
}

class NewOTPInputFormatter extends TextInputFormatter {
  String otpFormatter(value) {
    String numbers = value.replaceAll(RegExp(r'\D'), '');
    String internationalPhoneFormatted = numbers.isNotEmpty && numbers.length > 3
        ? '${numbers.substring(0, numbers.length > 3 ? 3 : null)}${numbers.length > 3 ? '-' : ''}${numbers.substring(3, numbers.length >= 6 ? 6 : null)}'
        : numbers;
    return internationalPhoneFormatted;
  }

  @override
  TextEditingValue formatEditUpdate(
      TextEditingValue oldValue, TextEditingValue newValue) {
    String text = newValue.text;

    if (newValue.selection.baseOffset == 0) {
      return newValue;
    }

    return newValue.copyWith(
        text: otpFormatter(text),
        selection: TextSelection.collapsed(
            offset: otpFormatter(text).length));
  }
}

class Formatters {
  static FractionalMoney toFractionalMoney(
    String value, {
    int decimals = 2,
    String currencyCode = '\$',
  }) {
    final balance = double.parse(value);
    final moneyData = Formatters.doubleToMoney(balance, decimals).split('.');
    final money = moneyData[0];
    final fractionalPart = moneyData.length > 1 ? moneyData[1] : '00';

    return FractionalMoney(
      money: money,
      fractionalPart: fractionalPart,
      currencyCode: currencyCode,
    );
  }

  static String toDateWithTime(String timeStamp) {
    final DateFormat formatter = DateFormat('MMM d, y, h:mm a');
    return formatter
        .format(DateTime.parse(timeStamp).add(const Duration(hours: 1)));
  }

  static String toTime(String date) {
    final DateFormat formatter = DateFormat('h:mm a');
    return formatter.format(DateTime.parse(date));
  }

  static dynamic toTimeOrDate(DateTime t) {
    if (t.day == DateTime.now().day) {
      return toTime(t.toLocal().toString());
    }

    return toDateWithTime(t.toLocal().toString());
  }

  static String doubleToMoney(double value, int decimals) {
    var fmtString = '#,###,###.';
    if (decimals < 1) {
      fmtString = '#,###,###';
    }

    for (int i = 0; i < decimals; i++) {
      fmtString += '#';
    }

    return NumberFormat(fmtString, 'en_US').format(value);
  }

  static String truncate(String address, [int len = 10]) {
    return '${address.substring(0, len)}...${address.substring(address.length - len + 3)}';
  }

  static String truncateAddress(String address) {
    return '${address.substring(0, 6)}...${address.substring(address.length - 6)}';
  }
}

class FractionalMoney {
  FractionalMoney({
    required this.money,
    required this.fractionalPart,
    required this.currencyCode,
  });

  final String money;
  final String fractionalPart;
  final String currencyCode;
}

String coinPNG(String symbol) =>
    'https://firebasestorage.googleapis.com/v0/b/busha-mobile/o/assets_png%2F${symbol.toUpperCase()}.png?alt=media';
