import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/assets/assets.dart';
import 'package:busha_commerce_flutter/src/utils/colors.dart';
import 'package:busha_commerce_flutter/src/utils/constants.dart';
import 'package:busha_commerce_flutter/src/utils/navigation_handler.dart';
import 'package:busha_commerce_flutter/src/utils/textstyle.dart';
import 'package:busha_commerce_flutter/src/views/auth/login_view_model.dart';
import 'package:busha_commerce_flutter/src/views/verification_view/verification_view.dart';
import 'package:busha_commerce_flutter/src/widgets/snackbar/snackbar_config.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

class LoginView extends StatelessWidget {
  const LoginView({super.key});

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder<LoginViewModel>.reactive(
        viewModelBuilder: () => LoginViewModel(),
        builder: (context, model, child) {
          return AppWrapper(
            onTapBack: () {
              NavigationHandler().pop(context);
            },
            onTapClose: () {
              NavigationHandler().navigatorPush(
                  buildContext: context,
                  route: const CancelTransactionView()
              );
            },
            child: Padding(
              padding: const EdgeInsets.symmetric(horizontal: kMediumSpacing),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const SizedBox(
                    height: kSmallSpacing,
                  ),
                  Text(
                    'Log in to your account',
                    style: context.headlineLarge,
                  ),
                  const SizedBox(
                    height: 4,
                  ),
                  Text(
                    'Enter your Busha account details',
                    style: context.labelMedium
                        .copyWith(fontWeight: FontWeight.w500),
                  ),
                  const SizedBox(
                    height: 24,
                  ),
                  Form(
                    child:  Column(
                        children: [
                          CommerceInputField(
                            errorText: model.errorMessage,
                            label: 'Email address',
                            controller: model.emailTextController,
                            onChanged: (v) => model.onEmailSet(v: v),
                          ),
                          const SizedBox(
                            height: kMediumSpacing,
                          ),
                          CommerceInputField(
                            isPassword: !model.showPassword!,
                            controller: model.passwordTextController,
                            onChanged: (v) => model.onPasswordSet(v: v),
                            suffixIcon: Container(
                              width: 48,
                              height: 15,
                              decoration: BoxDecoration(
                                color: Colors.white,
                                borderRadius: BorderRadius.circular(10),
                              ),
                              margin: const EdgeInsets.only(
                                right: 10,
                                top: 4,
                                bottom: 4,
                              ),
                              child: IconButton(
                                highlightColor: Colors.transparent,
                                splashColor: Colors.transparent,
                                onPressed: () => model.updatePasswordToggle(),
                                icon: model.showPassword!
                                    ? Assets.lib.src.assets.svgs.hide.svg(
                                        package: 'busha_commerce_flutter',
                                        height: 50,
                                        width: 50,
                                      )
                                    : Assets.lib.src.assets.svgs.eye.svg(
                                        package: 'busha_commerce_flutter',
                                        height: 50,
                                        width: 50,
                                      ),
                              ),
                            ),
                            label: 'Password',
                          ),
                        ],
                      ),
                  ),
                  const Spacer(),
                  const LoginButton(),
                  const SizedBox(
                    height: 24,
                  ),
                ],
              ),
            ),
          );
        },
    );
  }
}

class LoginButton extends ViewModelWidget<LoginViewModel> {
  const LoginButton({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context, LoginViewModel viewModel) {
    return CommerceButton(
      buttonColor: viewModel.canContinue
          ? CustomColors.buttonColor
          : CustomColors.fadedColor,
      padding: 0,
      onTap: () => viewModel.login(
        onCallBack: () async {
          NavigationHandler().navigatorReplace(
              buildContext: context,
              route: const VerificationView()
          );
        },
        onErrorCallBack: (e) {
          showSnackBar(
            context: context,
            message: e,
          );
        },
      ),
      isLoading: viewModel.isBusy,
      child: Text(
        'Login',
        style: context.headlineSmall.copyWith(
          color: viewModel.canContinue ? Colors.white : CustomColors.textColor,
        ),
      ),
    );
  }
}
