import 'package:busha_commerce_flutter/src/core/model/request/login_request.dart';
import 'package:busha_commerce_flutter/src/core/model/response/login_response.dart';
import 'package:busha_commerce_flutter/src/core/services/auth_service.dart';
import 'package:busha_commerce_flutter/src/utils/locator_setup.dart';
import 'package:flutter/cupertino.dart';
import 'package:stacked/stacked.dart';

typedef OnErrorCallBack = Function(String value);

class LoginViewModel extends BaseViewModel {
  final authService = serviceLocator<AuthService>();

  String email = '';
  String password = '';

  bool canContinue = false;

  bool hidePassword = true;

  bool showErrorMessage = false;
  String? errorMessage;

  bool? showPassword = false;

  TextEditingController emailTextController = TextEditingController();
  TextEditingController passwordTextController = TextEditingController();

  Future<void> login({
    required Function onCallBack,
    required OnErrorCallBack onErrorCallBack,
  }) async {
    authService.loginRequest = LoginRequest(email: email.trim(), password: password.trim());
    if (isBusy == false && email.isNotEmpty && password.isNotEmpty) {
      try {
        LoginResponse result = await runBusyFuture(
          authService.login(),
          throwException: true,
        );
        authService.confirmToken = result.confirmationToken;
        authService.confirmationMessage = result.message;
        
        if (authService.confirmToken != null) {
          onCallBack();
        } else {
          onErrorCallBack('Kindly open the Busha app and set up 2FA');
        }
      } catch (e) {
        debugPrint(e.toString());
        onErrorCallBack('$e');
      }
    }
  }

  void onEmailSet({required String v}) {
    email = v;
    if (password.isNotEmpty && email.isNotEmpty) {
      canContinue = true;
    } else {
      canContinue = false;
    }
  }

  void onPasswordSet({required String v}) {
    password = v;
    if (password.isNotEmpty && email.isNotEmpty) {
      canContinue = true;
    } else {
      canContinue = false;
    }
    notifyListeners();
  }

  void updatePasswordToggle() {
    if (showPassword == false) {
      showPassword = true;
    } else {
      showPassword = false;
    }
    notifyListeners();
  }

  void setErrorMessage(String? value) {
    errorMessage = value;
    showErrorMessage = errorMessage?.isNotEmpty ?? false;
  }
}
