import 'package:busha_commerce_flutter/src/assets/assets.dart';
import 'package:busha_commerce_flutter/src/core/core.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/views/brand/brand_section_model.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

import '../../widgets/commerce_button.dart';

class BrandSection extends StatelessWidget {
  const BrandSection(
      {Key? key,
      required this.isButtonVisible,
      this.onTap,
      this.horizontalPadding,
      this.buttonColor,
      this.verticalPadding,
      this.buttonChild,
      this.isButtonLoading})
      : super(key: key);

  final bool isButtonVisible;
  final void Function()? onTap;
  final Widget? buttonChild;
  final Color? buttonColor;
  final double? horizontalPadding;
  final double? verticalPadding;
  final bool? isButtonLoading;

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder<BrandSectionModel>.nonReactive(
      viewModelBuilder: () => BrandSectionModel(),
      builder: (_, model, __) {
        return Column(
          children: [
            Visibility(
              visible: isButtonVisible,
              child: Padding(
                padding: const EdgeInsets.symmetric(
                  horizontal: kLargeSpacing,
                  vertical: kLargeSpacing,
                ),
                child: CommerceButton(
                  verticalPadding: verticalPadding,
                  buttonColor: buttonColor,
                  padding: horizontalPadding,
                  onTap: onTap,
                  isLoading: isButtonLoading,
                  child: buttonChild!,
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(bottom: 8),
              child: SizedBox(
                height: kLargeSpacing,
                width: context.responsiveWidth,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    Text("Secured by",style: context.headlineMedium.copyWith(
                        fontWeight: FontWeight.w500,fontSize: 14
                    ),),
                    const SizedBox(
                      width: 8,
                    ),
                    Assets.lib.src.assets.pngs.logo.image(
                      package: 'busha_commerce_flutter',
                      height: kLargeSpacing,
                    ),
                    const SizedBox(
                      width: kSmallSpacing,
                    ),
                    const VerticalDivider(
                      thickness: 2,
                    ),
                    const SizedBox(
                      width: kSmallSpacing,
                    ),
                    GestureDetector(
                      onTap: () =>
                          model.openLink(CommerceUrls.termsOfServiceUrl),
                      child: Text(
                        "Terms",
                        style: context.headlineMedium.copyWith(
                          fontWeight: FontWeight.w500,fontSize: 14
                        ),
                      ),
                    ),
                    const SizedBox(
                      width: kMediumSpacing,
                    ),
                    GestureDetector(
                      onTap: () =>
                          model.openLink(CommerceUrls.privacyPolicyUrl),
                      child: Text(
                        "Privacy",
                        style: context.headlineMedium.copyWith(
                            fontWeight: FontWeight.w500,fontSize: 14
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ],
        );
      },
    );
  }
}
