import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/assets/assets.dart';
import 'package:busha_commerce_flutter/src/utils/navigation_handler.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/views/auth/login_view.dart';
import 'package:busha_commerce_flutter/src/views/entry/entry_view_model.dart';
import 'package:busha_commerce_flutter/src/views/select_asset/select_payment_asset_view.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

class EntryView extends StatelessWidget {
  const EntryView({super.key});

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder<EntryViewModel>.reactive(
      onViewModelReady: (model) => model.initialize(),
      viewModelBuilder: () => EntryViewModel(),
      builder: (context, model, child) {
        return Visibility(
          visible: !model.hasError,
          replacement: TransactionLayout(
            secondaryOnTap: () async {
              NavigationHandler().pop(context);
            },
            showPrimaryButton: false,
            showSecondaryButton: true,
            isSecondaryButtonBusy: model.isBusy,
            image: Assets.lib.src.assets.svgs.cancel.svg(
              package: 'busha_commerce_flutter',
            ),
            secondaryButtonLabel: 'Close',
            title: 'Error',
            subtitle: '${model.modelError}',
            //'There is an error with your checkout link or used key. Check and try again.',
          ),
          child: AppWrapper(
            onTapClose: () {
              NavigationHandler().navigatorPush(
                buildContext: context,
                route: const CancelTransactionView(),
              );
            },
            child: Builder(builder: (_) {
              if (!model.hasError && !model.isBusy) {
                return const _EntryBody();
              }

              return const _Loader();
            }),
          ),
        );
      },
    );
  }
}

class _EntryBody extends ViewModelWidget<EntryViewModel> {
  const _EntryBody({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context, model) {
    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: Column(
        children: [
          Container(
            width: 40,
            height: 40,
            decoration: const BoxDecoration(
              color: Color(0xffE94A3F),
              shape: BoxShape.circle,
            ),
            child: Center(
              child: Text(
                model.businessName.substring(0, 1).toUpperCase(),
                style: AppTextStyle.labelLarge.copyWith(
                  color: Colors.white,
                  fontWeight: FontWeight.bold,
                ),
              ),
            ),
          ),
          const SizedBox(
            height: 8,
          ),
          Text(
            model.businessName,
            style: context.headlineMedium,
          ),
          const SizedBox(
            height: 4,
          ),
          Text(
            'Merchant',
            style: context.labelMedium.copyWith(fontWeight: FontWeight.w500),
          ),
          const SizedBox(
            height: 24,
          ),
          Container(
            decoration: BoxDecoration(
              color: const Color(0xffF1F1F1),
              borderRadius: BorderRadius.circular(8),
            ),
            padding: const EdgeInsets.all(12),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Text(
                  'Amount to pay',
                  textAlign: TextAlign.left,
                  style:
                      context.labelLarge.copyWith(fontWeight: FontWeight.w500),
                ),
                Flexible(
                  child: Text(
                    "${model.currencyCode} ${model.totalAmount}",
                    textAlign: TextAlign.right,
                    maxLines: 3,
                    style: context.headlineSmall.copyWith(
                      fontWeight: FontWeight.w700,
                    ),
                  ),
                ),
              ],
            ),
          ),
          const SizedBox(
            height: 24,
          ),
          Row(
            children: [
              Text(
                'Select the payment method you want to use',
                textAlign: TextAlign.start,
                style: context.labelLarge.copyWith(fontWeight: FontWeight.w500),
              ),
            ],
          ),
          const SizedBox(
            height: 24,
          ),
          CustomListTile(
            onTap: () {
              NavigationHandler().navigatorPush(
                buildContext: context,
                route: const LoginView(),
              );
            },
            trailing: const SizedBox(
              width: 40,
              height: 40,
              child: Center(
                child: Icon(Icons.navigate_next_rounded),
              ),
            ),
            subtitle: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  'Make payment directly from your Busha account',
                  style:
                      context.labelMedium.copyWith(fontWeight: FontWeight.w500),
                ),
                const SizedBox(
                  height: 4,
                ),
                Chip(
                  backgroundColor: CustomColors.greyColor,
                  label: Text(
                    'Recommended',
                    style: context.labelMedium
                        .copyWith(fontSize: 12, fontWeight: FontWeight.w600),
                  ),
                ),
              ],
            ),
            title: Text(
              'Pay with Busha',
              style: context.headlineSmall,
            ),
            leading: Container(
              width: 40,
              decoration: BoxDecoration(
                color: const Color(0xffF1F1F1),
                borderRadius: BorderRadius.circular(18),
              ),
              height: 40,
              child: Center(
                child: Assets.lib.src.assets.svgs.busha.svg(
                  package: 'busha_commerce_flutter',
                ),
              ),
            ),
          ),
          const SizedBox(
            height: 24,
          ),
          CustomListTile(
            onTap: () {
              NavigationHandler().navigatorPush(
                buildContext: context,
                route: const SelectPaymentAssetView(
                  fromBushaPay: false,
                ),
              );
            },
            leading: Container(
              width: 40,
              decoration: BoxDecoration(
                color: const Color(0xffF1F1F1),
                borderRadius: BorderRadius.circular(18),
              ),
              height: 40,
              child: Center(
                child: Assets.lib.src.assets.svgs.wallet.svg(
                  package: 'busha_commerce_flutter',
                ),
              ),
            ),
            title: Text(
              'Pay with external wallet',
              style: context.headlineSmall,
            ),
            subtitle: Text(
              'Make payment from an external wallet',
              style: context.labelMedium.copyWith(fontWeight: FontWeight.w500),
            ),
            trailing: const SizedBox(
              width: 40,
              height: 40,
              child: Center(
                child: Icon(Icons.navigate_next_rounded),
              ),
            ),
          )
        ],
      ),
    );
  }
}

class _Loader extends StatelessWidget {
  const _Loader({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        CircularProgressIndicator(
          valueColor: AlwaysStoppedAnimation(
            CustomColors.buttonColor,
          ),
          strokeWidth: 2.5,
        )
      ],
    );
  }
}
