import 'dart:developer';

import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/core/constants/global.dart';
import 'package:busha_commerce_flutter/src/core/services/commerce_service.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:flutter/foundation.dart';
import 'package:stacked/stacked.dart';

class EntryViewModel extends BaseViewModel {
  final _commerceService = serviceLocator<CommerceService>();

  String businessName = '';
  String totalAmount = '';
  String currencyCode = '';
  String localAmount = '';
  String localCurrency = '';
  String? errorMessage;

  Future initialize() async {
    await checkout();
  }

  Future<void> checkout() async {
    try {
      setBusy(true);

      if (commercePaymentType == PaymentType.checkout) {
        final response = await _commerceService.getCheckout();
        businessName = response.data!.businessName!;
        localAmount = response.data!.localAmount!;
        localCurrency = response.data!.localCurrency!;
      } else {
        final response = await _commerceService.getInvoices();
        businessName = response.data.name;
        localAmount = response.data.localAmount;
        localCurrency = response.data.localCurrency;

        log(response.toString());
      }

      totalAmount = Formatters.toFractionalMoney(
        localAmount,
        currencyCode: localCurrency,
      ).money;
      currencyCode = localCurrency;
      notifyListeners();
    } catch (e) {
      setBusy(false);
      setError(e);
      errorMessage = '$e';
      notifyListeners();
      debugPrint('$e');
    }
    setBusy(false);
  }
}
