import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/views/payment/awaiting_payment/awaiting_payment_view.dart';
import 'package:busha_commerce_flutter/src/widgets/count/count_down.dart';
import 'package:flutter/material.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:qr_flutter/qr_flutter.dart';
import 'package:stacked/stacked.dart';

import '../../utils/navigation_handler.dart';
import 'make_payment_view_model.dart';

class MakePaymentView extends StatelessWidget {
  const MakePaymentView({super.key});

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder.reactive(
        viewModelBuilder: () => MakePaymentViewModel(),
        onViewModelReady: (model) => model.initialize(),
        builder: (context, model, child) {
          return AppWrapper(
            onTapButton: () async {
              NavigationHandler().navigatorPush(
                buildContext: context,
                route: const AwaitingPaymentView(),
              );
            },
            verticalPadding: 10,
            horizontalPadding: 0,
            buttonChild: Countdown(
              expiryDate: model.expire,
              value: (value) {
                model.updateTime(value);
              },
            ),
            isButtonVisible: true,
            onTapBack: () => NavigationHandler().pop(context),
            onTapClose: () {
              NavigationHandler().navigatorPush(
                  buildContext: context,
                  route: const CancelTransactionView()
              );
            },
            child: DefaultTabController(
              length: model.addresses.length,
              child: NestedScrollView(
                physics: const BouncingScrollPhysics(),
                headerSliverBuilder: (context, value) {
                  return [
                    SliverToBoxAdapter(
                      child: Padding(
                        padding: const EdgeInsets.symmetric(horizontal: 16),
                        child: Column(
                          children: [
                            const SizedBox(
                              height: kSmallSpacing,
                            ),
                            ListTile(
                              contentPadding: EdgeInsets.zero,
                              title: Text(
                                'Make Payment',
                                style: context.headlineLarge,
                              ),
                              subtitle: Padding(
                                padding: const EdgeInsets.symmetric(
                                    vertical: kSmallSpacing),
                                child: Text(
                                  'Send ${model.currentAsset} using the QR code or copy the address below.',
                                  style: context.labelMedium
                                      .copyWith(fontWeight: FontWeight.w500),
                                ),
                              ),
                            ),
                            // const SizedBox(
                            //   height: kSmallSpacing,
                            // ),
                          ],
                        ),
                      ),
                    ),
                    if (!model.isBusy && model.addresses.length > 1)
                      SliverPersistentHeader(
                        pinned: true,
                        delegate: CommercePersistentHeaderDelegate(
                          child: const AssetAddressViewTabSection(),
                        ),
                      )
                  ];
                },
                body: const Padding(
                  padding: EdgeInsets.symmetric(
                    horizontal: 16,
                  ),
                  child: AssetAddressViewTabContent(),
                ),
              ),
            ),
          );
        });
  }
}

class AssetAddressViewTabSection extends ViewModelWidget<MakePaymentViewModel> {
  const AssetAddressViewTabSection({super.key});

  @override
  Widget build(BuildContext context, MakePaymentViewModel viewModel) {
    return Container(
      decoration: const BoxDecoration(
        color: Colors.white,
      ),
      child: Stack(
        children: [
          Container(
            height: 48,
            decoration: BoxDecoration(
              border: Border(
                bottom: BorderSide(
                  color: CustomColors.greyColor,
                  width: 2,
                ),
              ),
            ),
          ),
          TabBar(
            tabs: viewModel.addresses.map(
              (address) {
                return Tab(
                  child: Text(
                    "${address.currencyId!} - ${address.chain!}",
                    style: Theme.of(context).textTheme.bodyText2!.copyWith(
                          fontWeight: FontWeight.w500,
                        ),
                  ),
                );
              },
            ).toList(),
            indicatorColor: CustomColors.textColor,
            indicatorWeight: 2,
          ),
        ],
      ),
    );
  }
}

class AssetAddressViewTabContent extends ViewModelWidget<MakePaymentViewModel> {
  const AssetAddressViewTabContent({super.key});

  @override
  Widget build(BuildContext context, MakePaymentViewModel viewModel) {
    return TabBarView(
      children: viewModel.addresses
          .map(
            (address) => SingleChildScrollView(
              physics: const BouncingScrollPhysics(),
              child: Column(
                children: [
                  viewModel.addresses.length > 1
                      ? const SizedBox(
                          height: 15,
                        )
                      : const SizedBox(
                          height: 0,
                        ),
                  Container(
                    width: context.responsiveWidth,
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(kMediumSpacing),
                      border: Border.all(
                        color: CustomColors.greyAlpha,
                      ),
                    ),
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: [
                        Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: QrImage(
                            data: address.address!,
                            size: 240,
                          ),
                        ),
                        Divider(
                          thickness: 1,
                          color: CustomColors.greyAlpha,
                        ),
                        ListTile(
                          contentPadding: const EdgeInsets.symmetric(
                            vertical: 10,
                            horizontal: 16,
                          ),
                          title: Text(
                            '${address.currencyId} Address (${address.chain})',
                            style: context.labelMedium.copyWith(
                                fontWeight: FontWeight.w500, fontSize: 12),
                          ),
                          subtitle: Text(
                            address.address!,
                            style: context.headlineSmall.copyWith(
                                fontWeight: FontWeight.w500, fontSize: 16),
                          ),
                          trailing: CopyButton(
                            text: address.address!,
                            itemName: 'Address',
                          ),
                        ),
                      ],
                    ),
                  ),
                  const SizedBox(
                    height: kMediumSpacing,
                  ),
                  Container(
                    width: context.responsiveWidth,
                    alignment: Alignment.center,
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(kMediumSpacing),
                      border: Border.all(
                        color: CustomColors.greyAlpha,
                      ),
                    ),
                    child: ListTile(
                      title: Text(
                        'Amount to send',
                        style: context.labelMedium,
                      ),
                      subtitle: Text(
                        '${viewModel.pricing[0].amount} ${viewModel.pricing[0].currencyId}(${viewModel.currency} ${viewModel.amountDisplay}) ',
                        style: context.headlineSmall,
                      ),
                      trailing: CopyButton(
                        text: '${viewModel.pricing[0].amount}',
                        itemName: 'Amount',
                      ),
                    ),
                    // trailing: Chip(
                    //   backgroundColor: BrandTheme.of(context).primaryColor,
                    //   label: Text(
                    //     'Copied',
                    //     style: context.headlineSmall.copyWith(
                    //       color: Colors.white,
                    //     ),
                    //   ),
                    // ),
                  ),
                ],
              ),
            ),
          )
          .toList(),
    );
  }
}
