import 'package:busha_commerce_flutter/src/core/services/commerce_service.dart';
import 'package:stacked/stacked.dart';

import '../../core/model/model.dart';
import '../../utils/utils.dart';

class MakePaymentViewModel extends BaseViewModel {
  final _commerceService = serviceLocator<CommerceService>();

  String? currentAsset;
  String amount = '';
  String amountDisplay = '';
  String? currency = '';
  String expire = "${DateTime.now()}";
  String remainingTime = '';
  List<ListChargesAddress> addresses = [];
  List<ListChargesPricing> pricing = [];
  List<String> chains = [];

  Future<void> initialize() async {
    expire = '${_commerceService.createChargesResponse!.data!.expiresAt}';
    currentAsset = _commerceService.selectedSupportedAsset;
    await transactionInformation();
    notifyListeners();
  }

  updateTime(value) {
    remainingTime = value;
    notifyListeners();
  }

  Future<void> transactionInformation() async {
    final chargeInfo = _commerceService.createChargesResponse!.data!;
    final data = _commerceService.selectedSupportedAsset;
    currentAddress(chargeInfo, data!);
    currentPricing(chargeInfo, data);
    supportedChains(chargeInfo, data);
    amount = chargeInfo.localAmount!;
    currency = chargeInfo.localCurrency!;

    amountDisplay = Formatters.toFractionalMoney(
      chargeInfo.localAmount!,
      currencyCode: chargeInfo.localCurrency!,
    ).money;

    notifyListeners();
  }

  void supportedChains(CreateChargesData chargeInfo, String data) {
    for (final chain in chargeInfo.supportedAssets!) {
      if (chain.currencyId == data) {
        chains.addAll(chain.chains);
      }
    }
  }

  void currentPricing(CreateChargesData chargeInfo, String data) {
    for (final price in chargeInfo.pricing!) {
      if (price.currencyId == data) {
        pricing.add(price);
      }
    }
  }

  void currentAddress(CreateChargesData chargeInfo, String data) {
    for (final address in chargeInfo.addresses!) {
      if (address.currencyId == data) {
        addresses.add(address);
      }
    }
  }
}
