import 'package:busha_commerce_flutter/src/assets/assets.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/views/payment/awaiting_payment/awaiting_payment_view_model.dart';
import 'package:busha_commerce_flutter/src/views/payment/multiple/multiple_transaction_view.dart';
import 'package:busha_commerce_flutter/src/views/payment/underpaid_transaction/underpaid_trasaction_view.dart';
import 'package:busha_commerce_flutter/src/views/views.dart';
import 'package:busha_commerce_flutter/src/widgets/widgets.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

import '../../../core/model/response/payment_response.dart';

class AwaitingPaymentView extends StatelessWidget {
  const AwaitingPaymentView({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder.reactive(
      onViewModelReady: (model) => model.initialize(),
      viewModelBuilder: () => AwaitingPaymentViewModel(),
      builder: (context, model, child) {
        Data? data = model.payment.data;
        if (model.paymentStatusMap[data?.status] == PaymentStatus.completed) {
          return PaymentSuccessful(
            date: data!.createdAt.toString(),
            total: "${data.paidAmount} ${data.currency}",
            reference: model.reference,
          );
        }
        String? contextCase = data?.context?.toUpperCase();
        if (model.paymentStatusMap[contextCase] == PaymentStatus.overpaid) {
          return OverpaidTransactionView(
            date: data!.createdAt.toString(),
            amountPaid: "${data.paidAmount}${data.currency}",
            amountExpected: "${data.expectedAmount}${data.currency}",
            reference: model.reference,
          );
        }
        if (model.paymentStatusMap[contextCase] == PaymentStatus.underpaid) {
          return UnderpaidTransactionView(
            date: data!.createdAt.toString(),
            amountPaid: "${data.paidAmount}${data.currency}",
            amountExpected: "${data.expectedAmount}${data.currency}",
            reference: model.reference,
          );
        }
        if (model.paymentStatusMap[contextCase] == PaymentStatus.multiple) {
          return MultipleTransactionView(
            date: data!.createdAt.toString(),
            total: "${data.paidAmount}${data.currency}",
            reference: model.reference,
          );
        }
        return GestureDetector(
          child: TransactionLayout(
            image: Image.asset(
              color: CustomColors.buttonColor,
              width: 130,
              Assets.lib.src.assets.pngs.loadingState.path,
              package: 'busha_commerce_flutter',

            ),

            title: 'Awaiting payment',
            subtitle:
                "We're constantly monitoring the network to detect a payment. We would send a confirmation once it is detected.",
          ),
        );
      },
    );
  }
}
