import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/views/payment/awaiting_payment/awaiting_payment_view_model.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

class MultipleTransactionView
    extends ViewModelWidget<AwaitingPaymentViewModel> {
  const MultipleTransactionView({
    super.key,
    required this.date,
    required this.reference,
    required this.total,
  });

  final String date;
  final String reference;
  final String total;

  @override
  Widget build(BuildContext context, viewModel) {
    return PaymentCompleteLayout(
      isPaymentMisMatched: true,
      title: 'Multiple Payment',
      onPrimaryButtonTap: () {
        viewModel.updateResponse(viewModel.payment);
        Navigator.of(context).popUntil((route) => route.isFirst);
      },
      paymentDetails: MultipleTransactionDetail(
        date: date,
        reference: reference,
        total: total,
      ),
      subtitle:
          'We have detected multiple payment. Please check your email for the next steps. ',
    );
  }
}

class MultipleTransactionDetail extends StatelessWidget {
  const MultipleTransactionDetail({
    Key? key,
    required this.date,
    required this.reference,
    required this.total,
  }) : super(key: key);

  final String date;
  final String reference;
  final String total;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Text(
              'Date & time',
              style: context.labelLarge.copyWith(fontWeight: FontWeight.w500),
            ),
            Text(
              Formatters.toDateWithTime(date),
              style:
                  context.headlineSmall.copyWith(fontWeight: FontWeight.w500),
            ),
          ],
        ),
        const SizedBox(
          height: 20,
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Text(
              'Reference',
              style: context.labelLarge.copyWith(fontWeight: FontWeight.w500),
            ),
            Flexible(
              child: Text(
                reference,
                maxLines: 2,
                textAlign: TextAlign.right,
                overflow: TextOverflow.ellipsis,
                style:
                    context.headlineSmall.copyWith(fontWeight: FontWeight.w500),
              ),
            ),
          ],
        ),
        const SizedBox(
          height: 20,
        ),
        const Divider(
          thickness: 1,
        ),
        const SizedBox(
          height: 20,
        ),
        total.isNotEmpty
            ? Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Text(
                    'Amount Paid',
                    style: context.labelLarge
                        .copyWith(fontWeight: FontWeight.w600),
                  ),
                  Flexible(
                    child: Text(
                      total,
                      maxLines: 2,
                      textAlign: TextAlign.right,
                      overflow: TextOverflow.ellipsis,
                      style: context.headlineSmall
                          .copyWith(fontWeight: FontWeight.w600),
                    ),
                  ),
                ],
              )
            : Container(),
      ],
    );
  }
}
