import 'package:cached_network_image/cached_network_image.dart';
import 'package:busha_commerce_flutter/src/assets/assets.dart';
import 'package:busha_commerce_flutter/src/utils/navigation_handler.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/views/select_asset/select_payment_asset_view_model.dart';
import 'package:busha_commerce_flutter/src/views/transactions/confirm_transaction_view.dart';
import 'package:busha_commerce_flutter/src/views/views.dart';
import 'package:busha_commerce_flutter/src/widgets/widgets.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

class SelectPaymentAssetView extends StatelessWidget {
  const SelectPaymentAssetView({super.key, this.fromBushaPay = true});

  final bool? fromBushaPay;

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder.reactive(
        viewModelBuilder: () => SelectPaymentAssetViewModel(),
        onViewModelReady: (model) => model.initialize(
            fromBushaPay: fromBushaPay
        ),
        builder: (context, model, child) {
          return AppWrapper(
            onTapBack: () {
              NavigationHandler().navigatorPush(
                  buildContext: context,
                  route: const CancelTransactionView()
              );
            },
            onTapClose: () {
              NavigationHandler().navigatorPush(
                  buildContext: context,
                  route: const CancelTransactionView()
              );
            },
            child: Padding(
              padding: const EdgeInsets.symmetric(horizontal: kLargeSpacing),
              child: !model.isBusy
                  ? Column(
                      mainAxisAlignment: MainAxisAlignment.start,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        const SizedBox(
                          height: kSmallSpacing,
                        ),
                        const AssetsHeader(),
                        const SizedBox(
                          height: kLargeSpacing,
                        ),
                        Expanded(
                          child: fromBushaPay == true ? ListView.separated(
                            physics: const NeverScrollableScrollPhysics(),
                            separatorBuilder: (context, index) =>
                                const Divider(),
                            itemCount: model.supportedWallets.length,
                            itemBuilder: (context, index) {
                              return AssetsListItem(
                                title: model.supportedWallets[index].name!,
                                subtitle:
                                model.supportedWallets[index].currency!,
                                price: model.supportedWallets[index].balance!,
                                imagePath: model.supportedWallets[index].logo!,
                                onTap: () async {
                                  model.updateSelectedWallet(index);
                                  NavigationHandler().navigatorPush(
                                    buildContext: context,
                                    route: const ConfirmTransactionView(),
                                  );
                                },
                              );
                            },
                          ) : ListView.separated(
                            physics: const NeverScrollableScrollPhysics(),
                            separatorBuilder: (context, index) =>
                            const Divider(),
                            itemCount: model.supportedAssets!.length,
                            itemBuilder: (context, index) {
                              return ListTile(
                                contentPadding: EdgeInsets.zero,
                                hoverColor: Colors.transparent,
                                onTap: () async {
                                  model.updateSelectedSupportedAsset(index);
                                  NavigationHandler().navigatorPush(
                                    buildContext: context,
                                    route: const MakePaymentView(),
                                  );
                                },
                                leading: SizedBox(
                                  height: 40,
                                  width: 40,
                                  child: ClipRRect(
                                    borderRadius: BorderRadius.circular(20.0),
                                    child: CachedNetworkImage(
                                      imageUrl: coinPNG(model.supportedAssets![index].currencyId),
                                      placeholder: (_, __) => Container(
                                        color: Theme.of(context).colorScheme.onPrimary.withOpacity(0.1),
                                      ),
                                      errorWidget: (context, url, error) => Container(
                                        color: Theme.of(context).colorScheme.onPrimary.withOpacity(0.1),
                                      ),
                                    ),
                                  ),
                                ),
                                title: Text(
                                  model.supportedAssets![index].name,
                                  style: context.headlineSmall.copyWith(
                                      color: Colors.black
                                  ),
                                ),
                              );
                            },
                          ),
                        )
                      ],
                    )
                  : Center(
                      child: CircularProgressIndicator(
                        valueColor: AlwaysStoppedAnimation(
                          CustomColors.buttonColor,
                        ),
                        strokeWidth: 2.5,
                      ),
                    ),
            ),
          );
        },
    );
  }
}

class AssetsHeader extends StatelessWidget {
  const AssetsHeader({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Text(
      'Select asset',
      style: context.headlineLarge,
    );
  }
}

class AssetsListItem extends StatelessWidget {
  const AssetsListItem({
    super.key,
    required this.title,
    required this.subtitle,
    required this.price,
    required this.imagePath,
    this.onTap,
  });

  final String title;
  final String subtitle;
  final String price;
  final String imagePath;
  final Function? onTap;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () => onTap!(),
      child: ListTile(
        contentPadding: EdgeInsets.zero,
        hoverColor: Colors.transparent,
        leading: SizedBox(
          height: 40,
          width: 40,
          child: ClipRRect(
            borderRadius: BorderRadius.circular(20.0),
            child: CachedNetworkImage(
              imageUrl: coinPNG(subtitle),
              placeholder: (_, __) => Container(
                color: Theme.of(context).colorScheme.onPrimary.withOpacity(0.1),
              ),
              errorWidget: (context, url, error) => Container(
                color: Theme.of(context).colorScheme.onPrimary.withOpacity(0.1),
              ),
            ),
          ),
        ),
        title: Text(
          title,
          style: context.headlineSmall.copyWith(
            color: Colors.black
          ),
        ),
        subtitle: Text(
          "Balance: $price $subtitle",
          style: context.labelMedium.copyWith(
              color: Colors.black.withOpacity(0.6)
          ),
        ),
        trailing: Assets.lib.src.assets.svgs.right.svg(
          package: 'busha_commerce_flutter',
          semanticsLabel: 'Arrow Forward Icon',
          color:  Colors.black.withOpacity(0.6)
        ),
      ),
    );
  }
}
