import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/core/constants/global.dart';
import 'package:busha_commerce_flutter/src/core/core.dart';
import 'package:busha_commerce_flutter/src/core/model/response/payment_response.dart';
import 'package:busha_commerce_flutter/src/core/model/response/supported_asset_response.dart';
import 'package:busha_commerce_flutter/src/core/services/account_service.dart';
import 'package:busha_commerce_flutter/src/core/services/commerce_service.dart';
import 'package:busha_commerce_flutter/src/core/services/payment_service.dart';
import 'package:flutter/foundation.dart';
import 'package:stacked/stacked.dart';

class SelectPaymentAssetViewModel extends ReactiveViewModel {
  final _accountService = serviceLocator<AccountService>();
  final _commerceService = serviceLocator<CommerceService>();
  final _paymentService = serviceLocator<PaymentService>();

  List<Wallet> supportedWallets = [];
  List<SupportedAsset>? supportedAssets = [];

  PaymentResponse get payment => _paymentService.payment;

  Future<void> initialize({bool? fromBushaPay = true}) async {
    try {
      if (fromBushaPay!) {
        supportedWallets.clear();
        CreateChargesData data = _commerceService.createChargesResponse!.data!;

        for (var element in data.supportedAssets!) {
          supportedWallets.add(_accountService.wallets!.data!
              .where(
                  (acctElement) => acctElement.currency == element.currencyId)
              .toList()[0]);
        }

        /// Sorting the list based on the one with more balance
        supportedWallets
            .sort((a, b) => b.fiat!.balance!.compareTo(a.fiat!.balance!));
      } else {
        await createCharge();
      }
    } catch (e) {
      debugPrint(e.toString());
    }

    notifyListeners();
  }

  void updateSelectedWallet(int index) {
    _commerceService.selectedWallet = supportedWallets[index];
  }

  void updateSelectedSupportedAsset(int index) {
    _commerceService.selectedSupportedAsset =
        supportedAssets![index].currencyId;
  }

  Future<void> createCharge() async {
    setBusy(true);
    try {
      if (commercePaymentType == PaymentType.checkout) {
        await _commerceService
            .createCheckoutCharge(
          name: _commerceService.customerName,
          email: _commerceService.customerEmail,
        )
            .then((value) {
          supportedAssets = value!.data!.supportedAssets;
          setBusy(false);
        });
      } else {
        await _commerceService
            .createInvoiceCharge(
          name: _commerceService.customerName,
          email: _commerceService.customerEmail,
        )
            .then((value) {
          supportedAssets = value!.data!.supportedAssets;
          setBusy(false);
        });
      }

      await _paymentService.initializeSocket();
    } catch (e) {
      setBusy(false);
      if (kDebugMode) {
        print(e);
      }
    }
  }

  @override
  List<ListenableServiceMixin> get listenableServices => [_paymentService];
}
