import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/utils/navigation_handler.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/views/transactions/confirm_transaction_view_model.dart';
import 'package:busha_commerce_flutter/src/views/transactions/verify_transaction/verify_transaction_view.dart';
import 'package:busha_commerce_flutter/src/widgets/snackbar/snackbar_config.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

class ConfirmTransactionView extends StatelessWidget {
  const ConfirmTransactionView({super.key});

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder.reactive(
        viewModelBuilder: () => ConfirmTransactionViewModel(),
        onViewModelReady: (model) => model.initialize(),
        builder: (context, model, child) {
          return AppWrapper(
            onTapButton: () async {
              model.initializePayout(onCallBack: () async {
                NavigationHandler().navigatorReplace(
                  buildContext: context,
                  route: const VerifyTransactionView(),
                );
              }, onErrorCallBack: (e) {
                showSnackBar(context: context, message: e);
              });
            },
            verticalPadding: 20,
            horizontalPadding: 0,
            buttonColor: CustomColors.buttonColor,
            isMainButtonLoading: model.isBusy,
            buttonChild: Text(
              'Continue',
              style: context.headlineSmall.copyWith(
                color: Colors.white,
              ),
            ),
            isButtonVisible: true,
            onTapBack: () {
              Navigator.pop(context);
            },
            onTapClose: () {
              NavigationHandler().navigatorPush(
                  buildContext: context, route: const CancelTransactionView());
            },
            child: Padding(
              padding: const EdgeInsets.symmetric(
                horizontal: kMediumSpacing,
              ),
              child: CustomScrollView(
                physics: const BouncingScrollPhysics(),
                slivers: [
                  SliverToBoxAdapter(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(
                          'Confirm transaction',
                          style: context.headlineLarge,
                        ),
                        const SizedBox(
                          height: 8,
                        ),
                        Text(
                          'You are about to pay ${model.merchantName} from your Busha wallet',
                          textAlign: TextAlign.start,
                          maxLines: 2,
                          style: context.labelMedium.copyWith(
                            fontWeight: FontWeight.w500,
                          ),
                        ),
                        const SizedBox(
                          height: 28,
                        ),
                        Column(
                          children: [
                            Row(
                              mainAxisAlignment: MainAxisAlignment.spaceBetween,
                              children: [
                                Text(
                                  'Amount',
                                  style: context.labelMedium.copyWith(
                                      fontWeight: FontWeight.w500,
                                      fontSize: 16),
                                ),
                                Text(
                                  '${model.pricing[0].amount} ${model.pricing[0].currencyId} (${model.currency} ${model.amountDisplay})',
                                  style: context.headlineSmall
                                      .copyWith(fontWeight: FontWeight.w500),
                                ),
                              ],
                            ),
                            const SizedBox(
                              height: 24,
                            ),
                            Row(
                              mainAxisAlignment: MainAxisAlignment.spaceBetween,
                              children: [
                                Text(
                                  'Fee',
                                  style: context.labelMedium.copyWith(
                                      fontWeight: FontWeight.w500,
                                      fontSize: 16),
                                ),
                                Text(
                                  '0 ${model.pricing[0].currencyId}',
                                  style: context.headlineSmall
                                      .copyWith(fontWeight: FontWeight.w500),
                                ),
                              ],
                            ),
                            const SizedBox(
                              height: 20,
                            ),
                            const Divider(
                              thickness: 1,
                            ),
                            const SizedBox(
                              height: 20,
                            ),
                            Row(
                              mainAxisAlignment: MainAxisAlignment.spaceBetween,
                              children: [
                                Text(
                                  'Total',
                                  style: context.labelMedium.copyWith(
                                      fontWeight: FontWeight.w500,
                                      fontSize: 16),
                                ),
                                Text(
                                  '${model.pricing[0].amount} ${model.pricing[0].currencyId} (${model.currency}${model.amountDisplay})',
                                  style: context.headlineSmall
                                      .copyWith(fontWeight: FontWeight.w500),
                                ),
                              ],
                            ),
                          ],
                        ),
                        const SizedBox(
                          height: 56,
                        ),
                        Container(
                          decoration: BoxDecoration(
                            color: CustomColors.fadedColor,
                            border: Border.all(
                              color: CustomColors.greyColor,
                            ),
                            borderRadius: BorderRadius.circular(8),
                          ),
                          child: Padding(
                            padding: const EdgeInsets.symmetric(
                                vertical: 16, horizontal: 8),
                            child: Column(
                              children: [
                                Row(
                                  children: [
                                    const SizedBox(
                                      width: 8,
                                    ),
                                    Container(
                                      height: 4,
                                      width: 4,
                                      decoration: BoxDecoration(
                                        shape: BoxShape.circle,
                                        color: CustomColors.textColorGrey,
                                      ),
                                    ),
                                    const SizedBox(
                                      width: 8,
                                    ),
                                    Flexible(
                                      child: RichText(
                                        maxLines: 4,
                                        overflow: TextOverflow.ellipsis,
                                        text: TextSpan(
                                          text:
                                              'The minimum transaction amount on Busha Commerce is',
                                          style: context.labelMedium.copyWith(
                                              fontWeight: FontWeight.w500),
                                          children: <TextSpan>[
                                            TextSpan(
                                              text: ' 0.0001 BTC ',
                                              style: TextStyle(
                                                  color: CustomColors.textColor,
                                                  fontWeight: FontWeight.w500,
                                                  fontSize: 14),
                                            ),
                                            const TextSpan(
                                                text: 'or NGN 5,000'),
                                          ],
                                        ),
                                      ),
                                    )
                                  ],
                                ),
                                const SizedBox(
                                  height: 8,
                                ),
                                Row(
                                  children: [
                                    const SizedBox(
                                      width: 8,
                                    ),
                                    Container(
                                      height: 4,
                                      width: 4,
                                      decoration: BoxDecoration(
                                        shape: BoxShape.circle,
                                        color: CustomColors.textColorGrey,
                                      ),
                                    ),
                                    const SizedBox(
                                      width: 8,
                                    ),
                                    Flexible(
                                      child: RichText(
                                        maxLines: 2,
                                        overflow: TextOverflow.ellipsis,
                                        text: TextSpan(
                                          text: 'You need to be a',
                                          style: context.labelMedium.copyWith(
                                              fontWeight: FontWeight.w500),
                                          children: <TextSpan>[
                                            TextSpan(
                                              text: ' Level 2 Customer ',
                                              style: TextStyle(
                                                  color: CustomColors.textColor,
                                                  fontWeight: FontWeight.w500,
                                                  fontSize: 14),
                                            ),
                                            const TextSpan(
                                                text:
                                                    'or above to make payments'),
                                          ],
                                        ),
                                      ),
                                    )
                                  ],
                                ),
                              ],
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          );
        });
  }
}
