import 'package:busha_commerce_flutter/src/core/services/commerce_service.dart';
import 'package:busha_commerce_flutter/src/core/services/payout_service.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:stacked/stacked.dart';

import '../../core/model/model.dart';

class ConfirmTransactionViewModel extends BaseViewModel {
  final _commerceService = serviceLocator<CommerceService>();
  final _payoutService = serviceLocator<PayoutService>();

  String amount = '';
  String amountDisplay = '';
  int selectedChain = 0;
  List<ListChargesAddress> addresses = [];
  List<ListChargesPricing> pricing = [];
  List<String> chains = [];
  String currency = '';

  String merchantName = '';

  void initialize() async {
    await transactionInformation();
  }

  void updateSelectedChain(int index){
    selectedChain = index;
    notifyListeners();
  }

  Future<void> transactionInformation() async {
    final chargeInfo = _commerceService.createChargesResponse!.data!;
    final data = _commerceService.selectedWallet!.currency!;
    if(_commerceService.checkoutResponse != null) {
      merchantName = _commerceService.checkoutResponse!.data!.businessName!;
    } else {

    }

    currentAddress(chargeInfo, data);
    currentPricing(chargeInfo, data);
    supportedChains(chargeInfo, data);
    amount = chargeInfo.localAmount!;
    currency = chargeInfo.localCurrency!;

    amountDisplay = Formatters.toFractionalMoney(
      chargeInfo.localAmount!,
      currencyCode: chargeInfo.localCurrency!,
    ).money;

    notifyListeners();
  }

  void supportedChains(CreateChargesData chargeInfo, String data) {
    for (final chain in chargeInfo.supportedAssets!) {
      if (chain.currencyId == data) {
        chains.addAll(chain.chains);
      }
    }
  }

  void currentPricing(CreateChargesData chargeInfo, String data) {
    for (final price in chargeInfo.pricing!) {
      if (price.currencyId == data) {
        pricing.add(price);
      }
    }
  }

  void currentAddress(CreateChargesData chargeInfo, String data) {
    for (final address in chargeInfo.addresses!) {
      if (address.currencyId == data) {
        addresses.add(address);
      }
    }
  }


  Future<void> initializePayout({Function? onCallBack, Function(String? e)? onErrorCallBack}) async {
    _payoutService.payoutRequest = PayoutRequest(
      amount: pricing[0].amount,
      address: addresses[selectedChain].address!,
      memo: '',
      chain: chains.isNotEmpty ? chains[selectedChain].toLowerCase() : addresses[selectedChain].chain,
      currency: pricing[0].currencyId!.toLowerCase()
    );

    setBusy(true);
    try {
      await _payoutService.initializeTransfer();
      setBusy(false);
      onCallBack!();
    } catch (e) {
      setBusy(false);
      onErrorCallBack!(e.toString());
    }

  }

}
