import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/utils/navigation_handler.dart';
import 'package:busha_commerce_flutter/src/views/payment/awaiting_payment/awaiting_payment_view.dart';
import 'package:busha_commerce_flutter/src/views/transactions/verify_transaction/verify_transaction_view_model.dart';
import 'package:busha_commerce_flutter/src/widgets/snackbar/snackbar_config.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

import 'verify_count_down.dart';

class VerifyTransactionView extends StatelessWidget {
  const VerifyTransactionView({super.key});

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder.reactive(
      onViewModelReady: (viewModel) => viewModel.initialize(),
      viewModelBuilder: () => VerifyTransactionViewModel(),
      builder: (context, model, child) {
        return AppWrapper(
          onTapBack: () {
            NavigationHandler().navigatorPush(
                buildContext: context, route: const CancelTransactionView());
          },
          child: Padding(
            padding: const EdgeInsets.symmetric(horizontal: kMediumSpacing),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                const SizedBox(
                  height: 4,
                ),
                Text(
                  'Verify transaction',
                  style: context.headlineLarge,
                ),
                const SizedBox(
                  height: 8,
                ),
                Text(
                  'Enter the 6-digit code sent to your email and authenticator app',
                  textAlign: TextAlign.start,
                  style:
                      context.labelMedium.copyWith(fontWeight: FontWeight.w500),
                ),
                const SizedBox(
                  height: 24,
                ),
                Form(
                  child: Container(
                    alignment: Alignment.center,
                    //width: MediaQuery.of(context).size.width - 32,
                    child: Column(
                      children: [
                        CommerceInputField(
                          onChanged: (v) => model.updateEmailCode(v),
                          label: 'Email code',
                          keyboard: TextInputType.number,
                          inputFormatters: [NewOTPInputFormatter()],
                        ),
                        const SizedBox(
                          height: 8,
                        ),
                        Visibility(
                          visible: !model.busy("resend"),
                          replacement: const _SmallLoader(),
                          child: Row(
                            children: [
                              Text(
                                'Resend code in',
                                style: context.labelMedium,
                              ),
                              const SizedBox(
                                width: 5,
                              ),
                              const VerifyCountdownTimer(),
                            ],
                          ),
                        ),
                        const SizedBox(
                          height: 16,
                        ),
                        CommerceInputField(
                          onChanged: (v) => model.updateAuthCode(v),
                          label: 'Authenticator code',
                          keyboard: TextInputType.number,
                          inputFormatters: [NewOTPInputFormatter()],
                        ),
                      ],
                    ),
                  ),
                ),
                const Spacer(),
                CommerceButton(
                  isLoading: model.isBusy,
                  buttonColor: model.buttonColor,
                  padding: 0,
                  onTap: () async {
                    model.verifyTransaction(
                      onCallBack: () {
                        NavigationHandler().navigatorReplace(
                          buildContext: context,
                          route: const AwaitingPaymentView(),
                        );
                      },
                      onErrorCallBack: (e) {
                        showSnackBar(
                          context: context,
                          message: e,
                        );
                      },
                    );
                  },
                  child: Text(
                    'Confirm payment',
                    style: context.headlineSmall.copyWith(
                      color: model.authCode.isNotEmpty &&
                              model.emailCode.isNotEmpty
                          ? Colors.white
                          : Colors.black,
                    ),
                  ),
                ),
                const SizedBox(
                  height: 24,
                ),
              ],
            ),
          ),
        );
      },
    );
  }
}

class _SmallLoader extends StatelessWidget {
  const _SmallLoader({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        SizedBox(
          height: 12,
          width: 12,
          child: CircularProgressIndicator(
            valueColor: AlwaysStoppedAnimation(
              CustomColors.buttonColor,
            ),
            strokeWidth: 3,
          ),
        ),
      ],
    );
  }
}
