import 'dart:developer';

import 'package:busha_commerce_flutter/src/core/api/api_exception.dart';
import 'package:busha_commerce_flutter/src/core/core.dart';
import 'package:busha_commerce_flutter/src/core/services/auth_service.dart';
import 'package:busha_commerce_flutter/src/core/services/payout_service.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/widgets/snackbar/snackbar_config.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

class VerifyTransactionViewModel extends BaseViewModel {
  final _payoutService = serviceLocator<PayoutService>();
  final _authService = serviceLocator<AuthService>();

  TextEditingController authController = TextEditingController();
  TextEditingController emailController = TextEditingController();

  Color buttonColor = CustomColors.fadedColor;

  String authCode = '';
  String emailCode = '';
  String currentTime = '';
  bool canResend = false;
  String maskedEmail = '';
  String remainingTime = '';
  String subTitle = '';

  DateTime dateTime = DateTime.now().subtract(const Duration(minutes: 59));

  Future<void> initialize() async {
    currentTime = dateTime.toUtc().toString().replaceAll('T', ' ');

    await maskEmailAddress();
  }

  Future<void> verifyTransaction({
    Function? onCallBack,
    required Function(String? e) onErrorCallBack,
  }) async {
    if (emailCode.isNotEmpty && authCode.isNotEmpty) {
      setBusy(true);
      _payoutService.payoutFinalizeRequest = PayoutFinalizeRequest(
        token: _payoutService.payoutFinalizeRequest!.token,
        emailCode: emailCode.replaceAll('-', ''),
        authCode: authCode.replaceAll('-', ''),
      );
      try {
        await _payoutService.finalizeTransfer();
        setBusy(false);
        onCallBack!();
      } catch (e) {
        setBusy(false);
        onErrorCallBack("$e");
        debugPrint(e.toString());
      }
    }
  }

  Future maskEmailAddress() async {
    String startPart = '';
    final userEmail = _authService.currentUser!.email!;
    var maskedEmailComponents = userEmail.split('@');
    for (int x = 0; x < maskedEmailComponents.first.length; x++) {
      if (x == 0 || x == 1) {
        startPart += maskedEmailComponents.first[x];
      } else {
        startPart += '*';
      }
    }

    maskedEmail = '$startPart@${maskedEmailComponents.last}';
  }

  void updateAuthCode(s) {
    authCode = s;
    updateColor();
    notifyListeners();
  }

  void updateEmailCode(s) {
    emailCode = s;
    updateColor();
    notifyListeners();
  }

  updateTime(value) {
    remainingTime = value;
    notifyListeners();
  }

  void updateColor() {
    if (emailCode.isNotEmpty && authCode.isNotEmpty) {
      buttonColor = CustomColors.buttonColor;
    } else {
      buttonColor = CustomColors.fadedColor;
    }
  }

  Future<void> resendCode(BuildContext context) async {
    try {
      await runBusyFuture(
        _payoutService.resendCode(),
        throwException: true,
        busyObject: 'resend',
      );
      notifyListeners();
    } on ApiException catch (e) {
      showSnackBar(
        context: context,
        message: e.message.toString(),
      );
    } catch (e) {
      log('$e');
    }
  }

  void updateCanResend() {
    if (canResend == false) {
      canResend = true;
    } else {
      canResend = false;
    }
    notifyListeners();
  }
}
