import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/utils/constants.dart';
import 'package:busha_commerce_flutter/src/utils/formatters.dart';
import 'package:busha_commerce_flutter/src/utils/navigation_handler.dart';
import 'package:busha_commerce_flutter/src/utils/textstyle.dart';
import 'package:busha_commerce_flutter/src/views/verification_view/verification_view_model.dart';
import 'package:busha_commerce_flutter/src/widgets/snackbar/snackbar_config.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

import '../select_asset/select_payment_asset_view.dart';

class VerificationView extends StatelessWidget {
  const VerificationView({super.key});

  @override
  Widget build(BuildContext context) {
    return ViewModelBuilder.reactive(
      viewModelBuilder: () => VerificationViewModel(),
      onViewModelReady: (model) => model.initialise(),
      builder: (context, model, child) {
        return AppWrapper(
          onTapBack: () {
            NavigationHandler().pop(context);
          },
          onTapClose: () {
            NavigationHandler().navigatorPush(
                buildContext: context,
                route: const CancelTransactionView()
            );
          },
          child: Padding(
            padding: const EdgeInsets.symmetric(horizontal: kMediumSpacing),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                const SizedBox(
                  height: kSmallSpacing,
                ),
                Text(
                  'Verify login',
                  style: context.headlineLarge,
                ),
                const SizedBox(
                  height: 4,
                ),
                Text(
                  model.message,
                  maxLines: 3,
                  style: context.labelMedium
                      .copyWith(fontWeight: FontWeight.w500),
                ),
                const SizedBox(
                  height: 24,
                ),
                Form(
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.start,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      CommerceInputField(
                        onChanged: (value){
                          model.updateColor(value);
                        },
                        controller: model.controller,
                        inputFormatters: [NewOTPInputFormatter()],
                        keyboard: TextInputType.number,
                        label: 'Authenticator code',
                        // hint: '00-00-00',
                      ),
                      const SizedBox(
                        height: 24,
                      ),
                    ],
                  ),
                ),
                const Spacer(),
                CommerceButton(
                  isLoading: model.isBusy,
                  buttonColor: model.buttonColor,
                  padding: 0,
                  onTap: () => model.verify(
                    onCallback: () async {

                      NavigationHandler().navigatorReplace(
                          buildContext: context, route: const SelectPaymentAssetView(
                        fromBushaPay: true,
                      ));

                    },
                    onErrorCallBack: (e) {
                      showSnackBar(
                        context: context,
                        message: e,
                      );
                    },
                  ),
                  child: Text(
                    'Login',
                    style: context.headlineSmall.copyWith(
                      color: model.controller.text.isNotEmpty ? Colors.white : Colors.black,
                    ),
                  ),
                ),
                const SizedBox(
                  height: 24,
                ),
              ],
            ),
          ),
        );
      },
    );
  }
}
