import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/core/constants/global.dart';
import 'package:busha_commerce_flutter/src/core/model/request/login_request.dart';
import 'package:busha_commerce_flutter/src/core/model/response/confirm_login_response.dart';
import 'package:busha_commerce_flutter/src/core/services/account_service.dart';
import 'package:busha_commerce_flutter/src/core/services/auth_service.dart';
import 'package:busha_commerce_flutter/src/core/services/commerce_service.dart';
import 'package:busha_commerce_flutter/src/core/services/payment_service.dart';
import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:stacked/stacked.dart';

class VerificationViewModel extends BaseViewModel {
  final _authService = serviceLocator<AuthService>();
  final _accountService = serviceLocator<AccountService>();
  final _commerceService = serviceLocator<CommerceService>();
  final _paymentService = serviceLocator<PaymentService>();

  Color buttonColor = CustomColors.fadedColor;

  TextEditingController controller = TextEditingController();

  String message = '';

  void initialise() {
    message = _authService.confirmationMessage ?? '';
    notifyListeners();
  }

  void verify({Function? onCallback, Function? onErrorCallBack}) async {
    if (controller.text.isNotEmpty) {
      _authService.loginRequest =
          LoginRequest(confirmationCode: controller.text.replaceAll('-', ''));

      try {
        /// Pass request
        final ConfirmLoginResponse result = await runBusyFuture(
          _authService.confirmLogin(),
          throwException: true,
        );

        _authService.accountKey = result.accessToken;

        setBusy(true);
        await _authService.getUser();
        await createCharge();
        await _accountService.getWallets();

        setBusy(false);
        onCallback!();
      } catch (e) {
        debugPrint(e.toString());
        onErrorCallBack!("$e");
      }
    }
  }

  Future<void> createCharge() async {
    try {
      if (commercePaymentType == PaymentType.checkout) {
        await _commerceService.createCheckoutCharge(
          email: _commerceService.customerEmail,
          name: _commerceService.customerName,
        );
      } else {
        await _commerceService.createInvoiceCharge(
          email: _commerceService.customerEmail,
          name: _commerceService.customerName,
        );
      }
      await _paymentService.initializeSocket();
    } catch (e) {
      if (kDebugMode) {
        print(e);
      }
    }
  }

  void updateColor(String value) {
    if (value.isNotEmpty) {
      buttonColor = CustomColors.buttonColor;
    } else {
      buttonColor = CustomColors.fadedColor;
    }

    notifyListeners();
  }
}
