import 'package:busha_commerce_flutter/src/assets/assets.dart';
import 'package:busha_commerce_flutter/src/views/brand/brand_section.dart';
import 'package:busha_commerce_flutter/src/views/cancel_transaction/cancel_transaction_view.dart';
import 'package:busha_commerce_flutter/src/widgets/hide_keyboard_container.dart';
import 'package:busha_commerce_flutter/src/widgets/widgets.dart';
import 'package:flutter/material.dart';

class AppWrapper extends StatelessWidget {
  const AppWrapper({
    super.key,
    required this.child,
    this.buttonChild,
    this.onTapBack,
    this.onTapClose,
    this.allowAppBar = true,
    this.isButtonVisible,
    this.buttonColor,
    this.horizontalPadding,
    this.verticalPadding,
    this.onTapButton,
    this.isMainButtonLoading,
  });
  final Widget child;
  final void Function()? onTapBack;
  final void Function()? onTapClose;
  final bool allowAppBar;
  final bool? isButtonVisible;
  final void Function()? onTapButton;
  final Widget? buttonChild;
  final Color? buttonColor;
  final double? horizontalPadding;
  final double? verticalPadding;
  final bool? isMainButtonLoading;

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () {
        showDialog<void>(context: context,
            builder: (BuildContext context) {
              return const CancelTransactionView();
            });
        return Future(() => true);
      },
      child: HideKeyboardContainer(
        child: Scaffold(
          backgroundColor: Theme.of(context).scaffoldBackgroundColor,
          resizeToAvoidBottomInset: false,
          appBar: allowAppBar
              ? CommerceAppBar(
                  allowBack: onTapBack != null,
                  allowClose: onTapClose != null,
                  onTapBack: onTapBack,
                  onTapClose: onTapClose,
                )
              : null,
          body: SafeArea(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Expanded(
                  child: child,
                ),
                BrandSection(
                  buttonColor: buttonColor,
                  verticalPadding: verticalPadding,
                  horizontalPadding: horizontalPadding,
                  onTap: onTapButton,
                  buttonChild: buttonChild ?? const Text(''),
                  isButtonVisible: isButtonVisible ?? false,
                  isButtonLoading: isMainButtonLoading ?? false,
                ),
                const SizedBox(height: 4,),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

/// CommerceAppBar is custom App to hold our close and back icons
class CommerceAppBar extends StatelessWidget with PreferredSizeWidget {
  const CommerceAppBar({
    super.key,
    this.onTapBack,
    this.onTapClose,
    this.allowBack = false,
    this.allowClose = false,
  });

  final bool? allowBack;
  final bool? allowClose;
  final void Function()? onTapBack;
  final void Function()? onTapClose;

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      bottom: false,
      child: ListTile(
        leading: allowBack!
            ? HeaderCard(
                onTap: onTapBack,
                semanticsLabel: 'Back Icon',
                icon: Assets.lib.src.assets.svgs.back,
              )
            : null,
        trailing: allowClose!
            ? HeaderCard(
                onTap: onTapClose,
                semanticsLabel: 'Close Icon',
                icon: Assets.lib.src.assets.svgs.close,
              )
            : null,
      ),
    );
  }

  @override
  Size get preferredSize => const Size(double.infinity, kToolbarHeight);
}

class HeaderCard extends StatelessWidget {
  const HeaderCard({
    super.key,
    required this.icon,
    this.semanticsLabel,
    this.onTap,
  });

  final SvgGenImage icon;
  final void Function()? onTap;
  final String? semanticsLabel;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      highlightColor: Colors.transparent,
      splashColor: Colors.transparent,
      onTap: onTap,
      child: Container(
        width: 32,
        height: 32,
        decoration: BoxDecoration(
          color: const Color(0xffF1F1F1),
          borderRadius: BorderRadius.circular(10),
        ),

        child: Center(
          child: icon.svg(
            semanticsLabel: semanticsLabel ?? 'Busha Icon',
            package: 'busha_commerce_flutter',
          ),
        ),
      ),
    );
  }
}
