import 'package:busha_commerce_flutter/src/utils/utils.dart';
import 'package:busha_commerce_flutter/src/widgets/snackbar/snackbar_config.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class CopyButton extends StatefulWidget {
  const CopyButton({Key? key, required this.text, required this.itemName}) : super(key: key);

  final String text;
  final String itemName;
  @override
  State<CopyButton> createState() => _CopyButtonState();
}

class _CopyButtonState extends State<CopyButton> {
  bool _isCopying = false;
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: _isCopying ? null : _copyAddress,
      child: AnimatedContainer(
        height: 40,
        duration: const Duration(milliseconds: 100),
        constraints: const BoxConstraints(maxWidth: 72.0),
        padding: const EdgeInsets.symmetric(
          vertical: 6,
          horizontal: 0,
        ),
        alignment: Alignment.center,
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(50),
          border: Border.all(
            color: _isCopying
                ? CustomColors().primaryColor
                : const Color(0xffF1F1F1),
          ),
          color: _isCopying
              ? CustomColors().primaryColor
              : const Color(0xffF1F1F1),
        ),
        child: Text(
          _isCopying ? 'Copied' : 'Copy',
          style: context.labelMedium.copyWith(
            fontWeight: FontWeight.bold,
            color: _isCopying ? Colors.white : Colors.black,
          ),
        ),
      ),
    );
  }

  /// only update the widget state if it's mounted.
  /// This helps to fix the dispose bug
  void _updateState() {
    if (mounted) {
      setState(() {});
    }
  }

  void _copyAddress() async {
    _isCopying = true;
    _updateState();

    await Clipboard.setData(ClipboardData(text: widget.text));
    showSnackBar(context: context, message: '${widget.itemName} copied');
    await Future.delayed(const Duration(seconds: 2));

    _isCopying = false;
    _updateState();
  }
}
