import 'dart:async';

import 'package:flutter/material.dart';
import 'package:intl/intl.dart';

class CountdownModel with ChangeNotifier {
  CountdownModel({required this.expiryDate, this.onTimeExpired});

  final String expiryDate;
  final Function()? onTimeExpired;

  DateTime? parsedExpiryDate;
  late Timer timer;

  String remainingTime = '00:00';
  bool isFirstTime = true;

  void initialise() {
    parsedExpiryDate = DateTime.parse(expiryDate);
    timer = Timer.periodic(
      const Duration(seconds: 0),
      _calculateRemainingTime,
    );
  }

  @override
  void dispose() {
    timer.cancel();
    super.dispose();
  }

  void _calculateRemainingTime(Timer timer) {
    DateFormat format = DateFormat('mm:ss');
    int now = DateTime.now().toLocal().millisecondsSinceEpoch;
    int expiryTimeInMilliseconds =
        parsedExpiryDate!.toLocal().millisecondsSinceEpoch;
    int millisecondsBetweenExpiryDateAndNow = expiryTimeInMilliseconds - now;
    if (millisecondsBetweenExpiryDateAndNow > 0) {
      Duration remaining = Duration(
        milliseconds: millisecondsBetweenExpiryDateAndNow,
      );
      remainingTime = format.format(
        DateTime.fromMillisecondsSinceEpoch(
          remaining.inMilliseconds,
        ),
      );
      isFirstTime = true;
    } else {
      remainingTime = '00:00';
      timer.cancel();
      if (onTimeExpired != null) {
        (onTimeExpired as Function)();
      }
    }

    notifyListeners();
  }
}
