import 'package:busha_commerce_flutter/src/utils/colors.dart';
import 'package:busha_commerce_flutter/src/utils/constants.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:busha_commerce_flutter/src/utils/textstyle.dart';

class CommerceInputField extends StatelessWidget {
  const CommerceInputField({
    super.key,
    this.controller,
    required this.label,
    this.currentNode,
    this.hint,
    this.nextNode,
    this.isPassword = false,
    this.autoValidate = false,
    this.errorText,
    this.onChanged,
    this.validator,
    this.borderColor,
    this.onSaved,
    this.keyboard,
    this.initialValue,
    this.copy = false,
    this.isEnabled = true,
    this.onFieldSubmitted,
    this.textInputAction,
    this.maxLines = 1,
    this.showHint = true,
    this.isForgottenOption = false,
    this.suffixIcon,
    this.inputFormatters,
  });

  final String label;
  final String? hint;
  final FocusNode? currentNode;
  final FocusNode? nextNode;
  final String? errorText;
  final bool isPassword;
  final Function(String)? onChanged;
  final FormFieldValidator<String>? validator;
  final Function(String?)? onSaved;
  final TextInputType? keyboard;
  final bool isEnabled;
  final bool copy;
  final bool autoValidate;
  final String? initialValue;
  final TextInputAction? textInputAction;
  final dynamic onFieldSubmitted;
  final int maxLines;
  final bool showHint;
  final TextEditingController? controller;
  final bool isForgottenOption;
  final List<TextInputFormatter>? inputFormatters;
  final Color? borderColor;
  final Widget? suffixIcon;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Row(
          children: [
            Text(
              label,
              style: context.labelMedium.copyWith(
                fontWeight: FontWeight.w600,color: CustomColors.textColor
              ),
            ),
          ],
        ),
        const SizedBox(
          height: kSmallSpacing,
        ),
        TextFormField(
          controller: controller,
          cursorColor: CustomColors().primaryColor,
          maxLines: maxLines,
          enabled: isEnabled,
          initialValue: initialValue,
          keyboardType: keyboard,
          obscureText: isPassword,
          onChanged: onChanged,
          validator: validator,
          focusNode: currentNode,
          autofocus: false,
          inputFormatters: inputFormatters,
          onSaved: (String? value) {
            FocusScope.of(context).requestFocus(nextNode);
            onSaved!(value);
          },
          onFieldSubmitted: (String value) {
            FocusScope.of(context).requestFocus(nextNode);
            onFieldSubmitted(value);
          },
          textInputAction: textInputAction,
          decoration: InputDecoration(
            fillColor: CustomColors.fadedColor,
            border: OutlineInputBorder(
              borderRadius: const BorderRadius.all(
                Radius.circular(15.0),
              ),
              borderSide: BorderSide(
                color: CustomColors.fadedColor.withOpacity(0.1),
                width: 1,
              ),
            ),
            enabledBorder: OutlineInputBorder(
              borderRadius: const BorderRadius.all(
                Radius.circular(15.0),
              ),
              borderSide: BorderSide(
                color: CustomColors.fadedColor.withOpacity(0.1),
                width: 1,
              ),
            ),
            hintStyle: TextStyle(
              color: CustomColors.textColorGrey,
              fontWeight: FontWeight.w700,
            ),
            hintText: hint ?? '',
            focusedBorder: OutlineInputBorder(
              borderRadius: const BorderRadius.all(
                Radius.circular(15.0),
              ),
              borderSide: BorderSide(
                color: CustomColors().primaryColor,
                width: 2,
              ),
            ),
            filled: true,
            contentPadding: const EdgeInsets.only(
              bottom: 18,
              left: 16.0,
              right: 16.0,
              top: 18,
            ),
            labelText: '',
            labelStyle: TextStyle(
              color: CustomColors.textColor,
              fontWeight: FontWeight.w400,
            ),
            suffixIcon: suffixIcon,
          ),
          style: TextStyle(
            color: CustomColors.textColor,
            fontWeight: FontWeight.w600,
            fontSize: 16,
          ),
        ),
      ],
    );
  }
}
