import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/assets/assets.dart';
import 'package:busha_commerce_flutter/src/utils/constants.dart';
import 'package:busha_commerce_flutter/src/utils/textstyle.dart';
import 'package:flutter/material.dart';

class PaymentCompleteLayout extends StatelessWidget {
  const PaymentCompleteLayout({
    this.isPaymentMisMatched = false,
    required this.title,
    required this.subtitle,
    required this.paymentDetails,
    this.primaryButtonText,
    required this.onPrimaryButtonTap,
    super.key,
  });

  final bool isPaymentMisMatched;
  final String title;
  final String subtitle;
  final Widget paymentDetails;
  final String? primaryButtonText;
  final Function onPrimaryButtonTap;

  @override
  Widget build(BuildContext context) {
    return AppWrapper(
      allowAppBar: false,
      child: Column(
        children: [
          SizedBox(
            height: 169,
            child: Stack(
              children: [
                SizedBox(
                  height: 130,
                  width: MediaQuery.of(context).size.width,
                  child: !isPaymentMisMatched
                      ? Assets.lib.src.assets.svgs.headerBgYellow.svg(
                          fit: BoxFit.cover,
                          package: 'busha_commerce_flutter',
                        )
                      : Assets.lib.src.assets.svgs.headerBgBlue.svg(
                          fit: BoxFit.cover,
                          package: 'busha_commerce_flutter',
                        ),
                ),
                Align(
                  alignment: Alignment.bottomCenter,
                  child: Container(
                    decoration: BoxDecoration(
                        color: Colors.white,
                        borderRadius: BorderRadius.circular(90),
                        border: Border.all(color: Colors.white, width: 6)),
                    child: !isPaymentMisMatched
                        ? Assets.lib.src.assets.svgs.doneYellow.svg(
                            height: 75,
                            package: 'busha_commerce_flutter',
                          )
                        : Assets.lib.src.assets.svgs.doneBlue.svg(
                            height: 75,
                            package: 'busha_commerce_flutter',
                          ),
                  ),
                ),
              ],
            ),
          ),
          const SizedBox(
            height: 20,
          ),
          ListTile(
            title: Padding(
              padding: const EdgeInsets.only(top: kSmallSpacing, bottom: 4),
              child: Text(
                title,
                textAlign: TextAlign.center,
                style: context.headlineLarge.copyWith(fontSize: 24),
              ),
            ),
            subtitle: Text(
              subtitle,
              textAlign: TextAlign.center,
              style: context.labelLarge.copyWith(fontWeight: FontWeight.w500),
            ),
          ),
          const SizedBox(
            height: kLargeSpacing,
          ),
          Padding(
            padding: const EdgeInsets.all(16.0),
            child: paymentDetails,
          ),
          const Spacer(),
          CommerceButton(
            onTap: () {
              onPrimaryButtonTap();
            },
            child: Text(
              primaryButtonText ?? 'Done',
              style: context.headlineSmall,
            ),
          ),
          const SizedBox(
            height: 20,
          ),
        ],
      ),
    );
  }
}
