import 'package:busha_commerce_flutter/busha_commerce_flutter.dart';
import 'package:busha_commerce_flutter/src/utils/colors.dart';
import 'package:busha_commerce_flutter/src/utils/constants.dart';
import 'package:flutter/material.dart';
import 'package:busha_commerce_flutter/src/utils/textstyle.dart';

class TransactionLayout extends StatelessWidget {
  const TransactionLayout({
    super.key,
    required this.image,
    required this.title,
    required this.subtitle,
    this.showPrimaryButton = false,
    this.showSecondaryButton = false,
    this.primaryButtonLabel,
    this.secondaryButtonLabel,
    this.isSecondaryButtonBusy = false,
    this.primaryOnTap,
    this.secondaryOnTap,
  });

  final Widget image;
  final String title;
  final String subtitle;
  final bool? showPrimaryButton;
  final bool? showSecondaryButton;
  final String? primaryButtonLabel;
  final String? secondaryButtonLabel;
  final bool? isSecondaryButtonBusy;
  final void Function()? primaryOnTap;
  final void Function()? secondaryOnTap;

  @override
  Widget build(BuildContext context) {
    return AppWrapper(
      child: Padding(
        padding: const EdgeInsets.symmetric(
          horizontal: kLargeSpacing,
        ),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Expanded(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  image,
                  ListTile(
                    title: Padding(
                      padding: const EdgeInsets.symmetric(
                        vertical: kLargeSpacing,
                      ),
                      child: Text(
                        title,
                        textAlign: TextAlign.center,
                        style: context.headlineLarge,
                      ),
                    ),
                    subtitle: Text(
                      subtitle,
                      textAlign: TextAlign.center,
                      style: context.labelLarge
                          .copyWith(fontWeight: FontWeight.w500),
                    ),
                  ),
                ],
              ),
            ),
            Visibility(
              visible: showPrimaryButton ?? false,
              child: CommerceButton(
                onTap: primaryOnTap,
                padding: 0,
                verticalPadding: 8,
                buttonColor: const Color(0xff12A633),
                child: Text(
                  primaryButtonLabel ?? 'No, Continue',
                  style: context.labelLarge.copyWith(
                    color: Colors.white,
                    fontWeight: FontWeight.w600,
                  ),
                ),
              ),
            ),
            Visibility(
              visible: showSecondaryButton!,
              child: CommerceButton(
                onTap: secondaryOnTap,
                padding: 0,
                child: !isSecondaryButtonBusy!
                    ? Text(
                        secondaryButtonLabel ?? 'Yes, Close',
                        style: context.labelLarge.copyWith(
                          fontWeight: FontWeight.w600,
                        ),
                      )
                    : CircularProgressIndicator(
                        valueColor: AlwaysStoppedAnimation(
                          CustomColors().primaryColor,
                        ),
                        strokeWidth: 2.5,
                      ),
              ),
            ),
            const SizedBox(
              height: 30,
            ),
          ],
        ),
      ),
    );
  }
}
